# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutoScalingConfigurationSummary(object):
    """
    Summary information for an autoscaling configuration.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AutoScalingConfigurationSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this AutoScalingConfigurationSummary.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this AutoScalingConfigurationSummary.
        :type display_name: str

        :param id:
            The value to assign to the id property of this AutoScalingConfigurationSummary.
        :type id: str

        :param cool_down_in_seconds:
            The value to assign to the cool_down_in_seconds property of this AutoScalingConfigurationSummary.
        :type cool_down_in_seconds: int

        :param is_enabled:
            The value to assign to the is_enabled property of this AutoScalingConfigurationSummary.
        :type is_enabled: bool

        :param resource:
            The value to assign to the resource property of this AutoScalingConfigurationSummary.
        :type resource: Resource

        :param defined_tags:
            The value to assign to the defined_tags property of this AutoScalingConfigurationSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this AutoScalingConfigurationSummary.
        :type freeform_tags: dict(str, str)

        :param time_created:
            The value to assign to the time_created property of this AutoScalingConfigurationSummary.
        :type time_created: datetime

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'display_name': 'str',
            'id': 'str',
            'cool_down_in_seconds': 'int',
            'is_enabled': 'bool',
            'resource': 'Resource',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'id': 'id',
            'cool_down_in_seconds': 'coolDownInSeconds',
            'is_enabled': 'isEnabled',
            'resource': 'resource',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags',
            'time_created': 'timeCreated'
        }

        self._compartment_id = None
        self._display_name = None
        self._id = None
        self._cool_down_in_seconds = None
        self._is_enabled = None
        self._resource = None
        self._defined_tags = None
        self._freeform_tags = None
        self._time_created = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this AutoScalingConfigurationSummary.
        The `OCID`__ of the compartment containing the autoscaling configuration.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this AutoScalingConfigurationSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this AutoScalingConfigurationSummary.
        The `OCID`__ of the compartment containing the autoscaling configuration.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this AutoScalingConfigurationSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        Gets the display_name of this AutoScalingConfigurationSummary.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :return: The display_name of this AutoScalingConfigurationSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this AutoScalingConfigurationSummary.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :param display_name: The display_name of this AutoScalingConfigurationSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def id(self):
        """
        **[Required]** Gets the id of this AutoScalingConfigurationSummary.
        The `OCID`__ of the autoscaling configuration.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this AutoScalingConfigurationSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AutoScalingConfigurationSummary.
        The `OCID`__ of the autoscaling configuration.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this AutoScalingConfigurationSummary.
        :type: str
        """
        self._id = id

    @property
    def cool_down_in_seconds(self):
        """
        Gets the cool_down_in_seconds of this AutoScalingConfigurationSummary.
        The minimum period of time to wait between scaling actions. The cooldown period gives the system time to stabilize
        before rescaling. The minimum value is 300 seconds, which is also the default.


        :return: The cool_down_in_seconds of this AutoScalingConfigurationSummary.
        :rtype: int
        """
        return self._cool_down_in_seconds

    @cool_down_in_seconds.setter
    def cool_down_in_seconds(self, cool_down_in_seconds):
        """
        Sets the cool_down_in_seconds of this AutoScalingConfigurationSummary.
        The minimum period of time to wait between scaling actions. The cooldown period gives the system time to stabilize
        before rescaling. The minimum value is 300 seconds, which is also the default.


        :param cool_down_in_seconds: The cool_down_in_seconds of this AutoScalingConfigurationSummary.
        :type: int
        """
        self._cool_down_in_seconds = cool_down_in_seconds

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this AutoScalingConfigurationSummary.
        Whether the autoscaling configuration is enabled.


        :return: The is_enabled of this AutoScalingConfigurationSummary.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this AutoScalingConfigurationSummary.
        Whether the autoscaling configuration is enabled.


        :param is_enabled: The is_enabled of this AutoScalingConfigurationSummary.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def resource(self):
        """
        **[Required]** Gets the resource of this AutoScalingConfigurationSummary.

        :return: The resource of this AutoScalingConfigurationSummary.
        :rtype: Resource
        """
        return self._resource

    @resource.setter
    def resource(self, resource):
        """
        Sets the resource of this AutoScalingConfigurationSummary.

        :param resource: The resource of this AutoScalingConfigurationSummary.
        :type: Resource
        """
        self._resource = resource

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this AutoScalingConfigurationSummary.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this AutoScalingConfigurationSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this AutoScalingConfigurationSummary.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this AutoScalingConfigurationSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this AutoScalingConfigurationSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this AutoScalingConfigurationSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this AutoScalingConfigurationSummary.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this AutoScalingConfigurationSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this AutoScalingConfigurationSummary.
        The date and time the AutoScalingConfiguration was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :return: The time_created of this AutoScalingConfigurationSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this AutoScalingConfigurationSummary.
        The date and time the AutoScalingConfiguration was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :param time_created: The time_created of this AutoScalingConfigurationSummary.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RestartDbSystemDetails(object):
    """
    DB System restart parameters.
    """

    #: A constant which can be used with the shutdown_type property of a RestartDbSystemDetails.
    #: This constant has a value of "IMMEDIATE"
    SHUTDOWN_TYPE_IMMEDIATE = "IMMEDIATE"

    #: A constant which can be used with the shutdown_type property of a RestartDbSystemDetails.
    #: This constant has a value of "FAST"
    SHUTDOWN_TYPE_FAST = "FAST"

    #: A constant which can be used with the shutdown_type property of a RestartDbSystemDetails.
    #: This constant has a value of "SLOW"
    SHUTDOWN_TYPE_SLOW = "SLOW"

    def __init__(self, **kwargs):
        """
        Initializes a new RestartDbSystemDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param shutdown_type:
            The value to assign to the shutdown_type property of this RestartDbSystemDetails.
            Allowed values for this property are: "IMMEDIATE", "FAST", "SLOW"
        :type shutdown_type: str

        """
        self.swagger_types = {
            'shutdown_type': 'str'
        }

        self.attribute_map = {
            'shutdown_type': 'shutdownType'
        }

        self._shutdown_type = None

    @property
    def shutdown_type(self):
        """
        **[Required]** Gets the shutdown_type of this RestartDbSystemDetails.
        The InnoDB shutdown mode to use, following the option
        \"`innodb_fast_shutdown`__\".

        __ https://dev.mysql.com/doc/refman/en/innodb-parameters.html#sysvar_innodb_fast_shutdown

        Allowed values for this property are: "IMMEDIATE", "FAST", "SLOW"


        :return: The shutdown_type of this RestartDbSystemDetails.
        :rtype: str
        """
        return self._shutdown_type

    @shutdown_type.setter
    def shutdown_type(self, shutdown_type):
        """
        Sets the shutdown_type of this RestartDbSystemDetails.
        The InnoDB shutdown mode to use, following the option
        \"`innodb_fast_shutdown`__\".

        __ https://dev.mysql.com/doc/refman/en/innodb-parameters.html#sysvar_innodb_fast_shutdown


        :param shutdown_type: The shutdown_type of this RestartDbSystemDetails.
        :type: str
        """
        allowed_values = ["IMMEDIATE", "FAST", "SLOW"]
        if not value_allowed_none_or_none_sentinel(shutdown_type, allowed_values):
            raise ValueError(
                "Invalid value for `shutdown_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._shutdown_type = shutdown_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AddImageShapeCompatibilityEntryDetails(object):
    """
    Image shape compatibility details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AddImageShapeCompatibilityEntryDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param memory_constraints:
            The value to assign to the memory_constraints property of this AddImageShapeCompatibilityEntryDetails.
        :type memory_constraints: ImageMemoryConstraints

        :param ocpu_constraints:
            The value to assign to the ocpu_constraints property of this AddImageShapeCompatibilityEntryDetails.
        :type ocpu_constraints: ImageOcpuConstraints

        """
        self.swagger_types = {
            'memory_constraints': 'ImageMemoryConstraints',
            'ocpu_constraints': 'ImageOcpuConstraints'
        }

        self.attribute_map = {
            'memory_constraints': 'memoryConstraints',
            'ocpu_constraints': 'ocpuConstraints'
        }

        self._memory_constraints = None
        self._ocpu_constraints = None

    @property
    def memory_constraints(self):
        """
        Gets the memory_constraints of this AddImageShapeCompatibilityEntryDetails.

        :return: The memory_constraints of this AddImageShapeCompatibilityEntryDetails.
        :rtype: ImageMemoryConstraints
        """
        return self._memory_constraints

    @memory_constraints.setter
    def memory_constraints(self, memory_constraints):
        """
        Sets the memory_constraints of this AddImageShapeCompatibilityEntryDetails.

        :param memory_constraints: The memory_constraints of this AddImageShapeCompatibilityEntryDetails.
        :type: ImageMemoryConstraints
        """
        self._memory_constraints = memory_constraints

    @property
    def ocpu_constraints(self):
        """
        Gets the ocpu_constraints of this AddImageShapeCompatibilityEntryDetails.

        :return: The ocpu_constraints of this AddImageShapeCompatibilityEntryDetails.
        :rtype: ImageOcpuConstraints
        """
        return self._ocpu_constraints

    @ocpu_constraints.setter
    def ocpu_constraints(self, ocpu_constraints):
        """
        Sets the ocpu_constraints of this AddImageShapeCompatibilityEntryDetails.

        :param ocpu_constraints: The ocpu_constraints of this AddImageShapeCompatibilityEntryDetails.
        :type: ImageOcpuConstraints
        """
        self._ocpu_constraints = ocpu_constraints

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateModelProvenanceDetails(object):
    """
    Model provenance gives data scientists information about the origin of their model. This information allows data scientists to reproduce the development environment in which the model was trained.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateModelProvenanceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param repository_url:
            The value to assign to the repository_url property of this UpdateModelProvenanceDetails.
        :type repository_url: str

        :param git_branch:
            The value to assign to the git_branch property of this UpdateModelProvenanceDetails.
        :type git_branch: str

        :param git_commit:
            The value to assign to the git_commit property of this UpdateModelProvenanceDetails.
        :type git_commit: str

        :param script_dir:
            The value to assign to the script_dir property of this UpdateModelProvenanceDetails.
        :type script_dir: str

        :param training_script:
            The value to assign to the training_script property of this UpdateModelProvenanceDetails.
        :type training_script: str

        """
        self.swagger_types = {
            'repository_url': 'str',
            'git_branch': 'str',
            'git_commit': 'str',
            'script_dir': 'str',
            'training_script': 'str'
        }

        self.attribute_map = {
            'repository_url': 'repositoryUrl',
            'git_branch': 'gitBranch',
            'git_commit': 'gitCommit',
            'script_dir': 'scriptDir',
            'training_script': 'trainingScript'
        }

        self._repository_url = None
        self._git_branch = None
        self._git_commit = None
        self._script_dir = None
        self._training_script = None

    @property
    def repository_url(self):
        """
        Gets the repository_url of this UpdateModelProvenanceDetails.
        For model reproducibility purposes. URL of the git repository associated with model training.


        :return: The repository_url of this UpdateModelProvenanceDetails.
        :rtype: str
        """
        return self._repository_url

    @repository_url.setter
    def repository_url(self, repository_url):
        """
        Sets the repository_url of this UpdateModelProvenanceDetails.
        For model reproducibility purposes. URL of the git repository associated with model training.


        :param repository_url: The repository_url of this UpdateModelProvenanceDetails.
        :type: str
        """
        self._repository_url = repository_url

    @property
    def git_branch(self):
        """
        Gets the git_branch of this UpdateModelProvenanceDetails.
        For model reproducibility purposes. Branch of the git repository associated with model training.


        :return: The git_branch of this UpdateModelProvenanceDetails.
        :rtype: str
        """
        return self._git_branch

    @git_branch.setter
    def git_branch(self, git_branch):
        """
        Sets the git_branch of this UpdateModelProvenanceDetails.
        For model reproducibility purposes. Branch of the git repository associated with model training.


        :param git_branch: The git_branch of this UpdateModelProvenanceDetails.
        :type: str
        """
        self._git_branch = git_branch

    @property
    def git_commit(self):
        """
        Gets the git_commit of this UpdateModelProvenanceDetails.
        For model reproducibility purposes. Commit ID of the git repository associated with model training.


        :return: The git_commit of this UpdateModelProvenanceDetails.
        :rtype: str
        """
        return self._git_commit

    @git_commit.setter
    def git_commit(self, git_commit):
        """
        Sets the git_commit of this UpdateModelProvenanceDetails.
        For model reproducibility purposes. Commit ID of the git repository associated with model training.


        :param git_commit: The git_commit of this UpdateModelProvenanceDetails.
        :type: str
        """
        self._git_commit = git_commit

    @property
    def script_dir(self):
        """
        Gets the script_dir of this UpdateModelProvenanceDetails.
        For model reproducibility purposes. Path to model artifacts.


        :return: The script_dir of this UpdateModelProvenanceDetails.
        :rtype: str
        """
        return self._script_dir

    @script_dir.setter
    def script_dir(self, script_dir):
        """
        Sets the script_dir of this UpdateModelProvenanceDetails.
        For model reproducibility purposes. Path to model artifacts.


        :param script_dir: The script_dir of this UpdateModelProvenanceDetails.
        :type: str
        """
        self._script_dir = script_dir

    @property
    def training_script(self):
        """
        Gets the training_script of this UpdateModelProvenanceDetails.
        For model reproducibility purposes. Path to the python script or notebook in which the model was trained.\"


        :return: The training_script of this UpdateModelProvenanceDetails.
        :rtype: str
        """
        return self._training_script

    @training_script.setter
    def training_script(self, training_script):
        """
        Sets the training_script of this UpdateModelProvenanceDetails.
        For model reproducibility purposes. Path to the python script or notebook in which the model was trained.\"


        :param training_script: The training_script of this UpdateModelProvenanceDetails.
        :type: str
        """
        self._training_script = training_script

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UsageStatusItem(object):
    """
    UsageStatusItem
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UsageStatusItem object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param data_type:
            The value to assign to the data_type property of this UsageStatusItem.
        :type data_type: str

        :param is_multi_valued:
            The value to assign to the is_multi_valued property of this UsageStatusItem.
        :type is_multi_valued: bool

        :param current_usage:
            The value to assign to the current_usage property of this UsageStatusItem.
        :type current_usage: int

        :param max_available:
            The value to assign to the max_available property of this UsageStatusItem.
        :type max_available: int

        """
        self.swagger_types = {
            'data_type': 'str',
            'is_multi_valued': 'bool',
            'current_usage': 'int',
            'max_available': 'int'
        }

        self.attribute_map = {
            'data_type': 'dataType',
            'is_multi_valued': 'isMultiValued',
            'current_usage': 'currentUsage',
            'max_available': 'maxAvailable'
        }

        self._data_type = None
        self._is_multi_valued = None
        self._current_usage = None
        self._max_available = None

    @property
    def data_type(self):
        """
        Gets the data_type of this UsageStatusItem.
        data type


        :return: The data_type of this UsageStatusItem.
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """
        Sets the data_type of this UsageStatusItem.
        data type


        :param data_type: The data_type of this UsageStatusItem.
        :type: str
        """
        self._data_type = data_type

    @property
    def is_multi_valued(self):
        """
        Gets the is_multi_valued of this UsageStatusItem.
        is the field multi valued


        :return: The is_multi_valued of this UsageStatusItem.
        :rtype: bool
        """
        return self._is_multi_valued

    @is_multi_valued.setter
    def is_multi_valued(self, is_multi_valued):
        """
        Sets the is_multi_valued of this UsageStatusItem.
        is the field multi valued


        :param is_multi_valued: The is_multi_valued of this UsageStatusItem.
        :type: bool
        """
        self._is_multi_valued = is_multi_valued

    @property
    def current_usage(self):
        """
        Gets the current_usage of this UsageStatusItem.
        current usage


        :return: The current_usage of this UsageStatusItem.
        :rtype: int
        """
        return self._current_usage

    @current_usage.setter
    def current_usage(self, current_usage):
        """
        Sets the current_usage of this UsageStatusItem.
        current usage


        :param current_usage: The current_usage of this UsageStatusItem.
        :type: int
        """
        self._current_usage = current_usage

    @property
    def max_available(self):
        """
        Gets the max_available of this UsageStatusItem.
        maximum available


        :return: The max_available of this UsageStatusItem.
        :rtype: int
        """
        return self._max_available

    @max_available.setter
    def max_available(self, max_available):
        """
        Sets the max_available of this UsageStatusItem.
        maximum available


        :param max_available: The max_available of this UsageStatusItem.
        :type: int
        """
        self._max_available = max_available

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceConfigurationLaunchOptions(object):
    """
    Options for tuning the compatibility and performance of VM shapes. The values that you specify override any
    default values.
    """

    #: A constant which can be used with the boot_volume_type property of a InstanceConfigurationLaunchOptions.
    #: This constant has a value of "ISCSI"
    BOOT_VOLUME_TYPE_ISCSI = "ISCSI"

    #: A constant which can be used with the boot_volume_type property of a InstanceConfigurationLaunchOptions.
    #: This constant has a value of "SCSI"
    BOOT_VOLUME_TYPE_SCSI = "SCSI"

    #: A constant which can be used with the boot_volume_type property of a InstanceConfigurationLaunchOptions.
    #: This constant has a value of "IDE"
    BOOT_VOLUME_TYPE_IDE = "IDE"

    #: A constant which can be used with the boot_volume_type property of a InstanceConfigurationLaunchOptions.
    #: This constant has a value of "VFIO"
    BOOT_VOLUME_TYPE_VFIO = "VFIO"

    #: A constant which can be used with the boot_volume_type property of a InstanceConfigurationLaunchOptions.
    #: This constant has a value of "PARAVIRTUALIZED"
    BOOT_VOLUME_TYPE_PARAVIRTUALIZED = "PARAVIRTUALIZED"

    #: A constant which can be used with the firmware property of a InstanceConfigurationLaunchOptions.
    #: This constant has a value of "BIOS"
    FIRMWARE_BIOS = "BIOS"

    #: A constant which can be used with the firmware property of a InstanceConfigurationLaunchOptions.
    #: This constant has a value of "UEFI_64"
    FIRMWARE_UEFI_64 = "UEFI_64"

    #: A constant which can be used with the network_type property of a InstanceConfigurationLaunchOptions.
    #: This constant has a value of "E1000"
    NETWORK_TYPE_E1000 = "E1000"

    #: A constant which can be used with the network_type property of a InstanceConfigurationLaunchOptions.
    #: This constant has a value of "VFIO"
    NETWORK_TYPE_VFIO = "VFIO"

    #: A constant which can be used with the network_type property of a InstanceConfigurationLaunchOptions.
    #: This constant has a value of "PARAVIRTUALIZED"
    NETWORK_TYPE_PARAVIRTUALIZED = "PARAVIRTUALIZED"

    #: A constant which can be used with the remote_data_volume_type property of a InstanceConfigurationLaunchOptions.
    #: This constant has a value of "ISCSI"
    REMOTE_DATA_VOLUME_TYPE_ISCSI = "ISCSI"

    #: A constant which can be used with the remote_data_volume_type property of a InstanceConfigurationLaunchOptions.
    #: This constant has a value of "SCSI"
    REMOTE_DATA_VOLUME_TYPE_SCSI = "SCSI"

    #: A constant which can be used with the remote_data_volume_type property of a InstanceConfigurationLaunchOptions.
    #: This constant has a value of "IDE"
    REMOTE_DATA_VOLUME_TYPE_IDE = "IDE"

    #: A constant which can be used with the remote_data_volume_type property of a InstanceConfigurationLaunchOptions.
    #: This constant has a value of "VFIO"
    REMOTE_DATA_VOLUME_TYPE_VFIO = "VFIO"

    #: A constant which can be used with the remote_data_volume_type property of a InstanceConfigurationLaunchOptions.
    #: This constant has a value of "PARAVIRTUALIZED"
    REMOTE_DATA_VOLUME_TYPE_PARAVIRTUALIZED = "PARAVIRTUALIZED"

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceConfigurationLaunchOptions object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param boot_volume_type:
            The value to assign to the boot_volume_type property of this InstanceConfigurationLaunchOptions.
            Allowed values for this property are: "ISCSI", "SCSI", "IDE", "VFIO", "PARAVIRTUALIZED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type boot_volume_type: str

        :param firmware:
            The value to assign to the firmware property of this InstanceConfigurationLaunchOptions.
            Allowed values for this property are: "BIOS", "UEFI_64", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type firmware: str

        :param network_type:
            The value to assign to the network_type property of this InstanceConfigurationLaunchOptions.
            Allowed values for this property are: "E1000", "VFIO", "PARAVIRTUALIZED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type network_type: str

        :param remote_data_volume_type:
            The value to assign to the remote_data_volume_type property of this InstanceConfigurationLaunchOptions.
            Allowed values for this property are: "ISCSI", "SCSI", "IDE", "VFIO", "PARAVIRTUALIZED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type remote_data_volume_type: str

        :param is_pv_encryption_in_transit_enabled:
            The value to assign to the is_pv_encryption_in_transit_enabled property of this InstanceConfigurationLaunchOptions.
        :type is_pv_encryption_in_transit_enabled: bool

        :param is_consistent_volume_naming_enabled:
            The value to assign to the is_consistent_volume_naming_enabled property of this InstanceConfigurationLaunchOptions.
        :type is_consistent_volume_naming_enabled: bool

        """
        self.swagger_types = {
            'boot_volume_type': 'str',
            'firmware': 'str',
            'network_type': 'str',
            'remote_data_volume_type': 'str',
            'is_pv_encryption_in_transit_enabled': 'bool',
            'is_consistent_volume_naming_enabled': 'bool'
        }

        self.attribute_map = {
            'boot_volume_type': 'bootVolumeType',
            'firmware': 'firmware',
            'network_type': 'networkType',
            'remote_data_volume_type': 'remoteDataVolumeType',
            'is_pv_encryption_in_transit_enabled': 'isPvEncryptionInTransitEnabled',
            'is_consistent_volume_naming_enabled': 'isConsistentVolumeNamingEnabled'
        }

        self._boot_volume_type = None
        self._firmware = None
        self._network_type = None
        self._remote_data_volume_type = None
        self._is_pv_encryption_in_transit_enabled = None
        self._is_consistent_volume_naming_enabled = None

    @property
    def boot_volume_type(self):
        """
        Gets the boot_volume_type of this InstanceConfigurationLaunchOptions.
        Emulation type for the boot volume.
        * `ISCSI` - ISCSI attached block storage device.
        * `SCSI` - Emulated SCSI disk.
        * `IDE` - Emulated IDE disk.
        * `VFIO` - Direct attached Virtual Function storage.  This is the default option for local data
        volumes on Oracle provided images.
        * `PARAVIRTUALIZED` - Paravirtualized disk. This is the default for boot volumes and remote block
        storage volumes on Oracle-provided images.

        Allowed values for this property are: "ISCSI", "SCSI", "IDE", "VFIO", "PARAVIRTUALIZED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The boot_volume_type of this InstanceConfigurationLaunchOptions.
        :rtype: str
        """
        return self._boot_volume_type

    @boot_volume_type.setter
    def boot_volume_type(self, boot_volume_type):
        """
        Sets the boot_volume_type of this InstanceConfigurationLaunchOptions.
        Emulation type for the boot volume.
        * `ISCSI` - ISCSI attached block storage device.
        * `SCSI` - Emulated SCSI disk.
        * `IDE` - Emulated IDE disk.
        * `VFIO` - Direct attached Virtual Function storage.  This is the default option for local data
        volumes on Oracle provided images.
        * `PARAVIRTUALIZED` - Paravirtualized disk. This is the default for boot volumes and remote block
        storage volumes on Oracle-provided images.


        :param boot_volume_type: The boot_volume_type of this InstanceConfigurationLaunchOptions.
        :type: str
        """
        allowed_values = ["ISCSI", "SCSI", "IDE", "VFIO", "PARAVIRTUALIZED"]
        if not value_allowed_none_or_none_sentinel(boot_volume_type, allowed_values):
            boot_volume_type = 'UNKNOWN_ENUM_VALUE'
        self._boot_volume_type = boot_volume_type

    @property
    def firmware(self):
        """
        Gets the firmware of this InstanceConfigurationLaunchOptions.
        Firmware used to boot VM.  Select the option that matches your operating system.
        * `BIOS` - Boot VM using BIOS style firmware.  This is compatible with both 32 bit and 64 bit operating
        systems that boot using MBR style bootloaders.
        * `UEFI_64` - Boot VM using UEFI style firmware compatible with 64 bit operating systems.  This is the
        default for Oracle-provided images.

        Allowed values for this property are: "BIOS", "UEFI_64", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The firmware of this InstanceConfigurationLaunchOptions.
        :rtype: str
        """
        return self._firmware

    @firmware.setter
    def firmware(self, firmware):
        """
        Sets the firmware of this InstanceConfigurationLaunchOptions.
        Firmware used to boot VM.  Select the option that matches your operating system.
        * `BIOS` - Boot VM using BIOS style firmware.  This is compatible with both 32 bit and 64 bit operating
        systems that boot using MBR style bootloaders.
        * `UEFI_64` - Boot VM using UEFI style firmware compatible with 64 bit operating systems.  This is the
        default for Oracle-provided images.


        :param firmware: The firmware of this InstanceConfigurationLaunchOptions.
        :type: str
        """
        allowed_values = ["BIOS", "UEFI_64"]
        if not value_allowed_none_or_none_sentinel(firmware, allowed_values):
            firmware = 'UNKNOWN_ENUM_VALUE'
        self._firmware = firmware

    @property
    def network_type(self):
        """
        Gets the network_type of this InstanceConfigurationLaunchOptions.
        Emulation type for the physical network interface card (NIC).
        * `E1000` - Emulated Gigabit ethernet controller.  Compatible with Linux e1000 network driver.
        * `VFIO` - Direct attached Virtual Function network controller. This is the networking type
        when you launch an instance using hardware-assisted (SR-IOV) networking.
        * `PARAVIRTUALIZED` - VM instances launch with paravirtualized devices using VirtIO drivers.

        Allowed values for this property are: "E1000", "VFIO", "PARAVIRTUALIZED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The network_type of this InstanceConfigurationLaunchOptions.
        :rtype: str
        """
        return self._network_type

    @network_type.setter
    def network_type(self, network_type):
        """
        Sets the network_type of this InstanceConfigurationLaunchOptions.
        Emulation type for the physical network interface card (NIC).
        * `E1000` - Emulated Gigabit ethernet controller.  Compatible with Linux e1000 network driver.
        * `VFIO` - Direct attached Virtual Function network controller. This is the networking type
        when you launch an instance using hardware-assisted (SR-IOV) networking.
        * `PARAVIRTUALIZED` - VM instances launch with paravirtualized devices using VirtIO drivers.


        :param network_type: The network_type of this InstanceConfigurationLaunchOptions.
        :type: str
        """
        allowed_values = ["E1000", "VFIO", "PARAVIRTUALIZED"]
        if not value_allowed_none_or_none_sentinel(network_type, allowed_values):
            network_type = 'UNKNOWN_ENUM_VALUE'
        self._network_type = network_type

    @property
    def remote_data_volume_type(self):
        """
        Gets the remote_data_volume_type of this InstanceConfigurationLaunchOptions.
        Emulation type for volume.
        * `ISCSI` - ISCSI attached block storage device.
        * `SCSI` - Emulated SCSI disk.
        * `IDE` - Emulated IDE disk.
        * `VFIO` - Direct attached Virtual Function storage.  This is the default option for local data
        volumes on Oracle provided images.
        * `PARAVIRTUALIZED` - Paravirtualized disk. This is the default for boot volumes and remote block
        storage volumes on Oracle-provided images.

        Allowed values for this property are: "ISCSI", "SCSI", "IDE", "VFIO", "PARAVIRTUALIZED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The remote_data_volume_type of this InstanceConfigurationLaunchOptions.
        :rtype: str
        """
        return self._remote_data_volume_type

    @remote_data_volume_type.setter
    def remote_data_volume_type(self, remote_data_volume_type):
        """
        Sets the remote_data_volume_type of this InstanceConfigurationLaunchOptions.
        Emulation type for volume.
        * `ISCSI` - ISCSI attached block storage device.
        * `SCSI` - Emulated SCSI disk.
        * `IDE` - Emulated IDE disk.
        * `VFIO` - Direct attached Virtual Function storage.  This is the default option for local data
        volumes on Oracle provided images.
        * `PARAVIRTUALIZED` - Paravirtualized disk. This is the default for boot volumes and remote block
        storage volumes on Oracle-provided images.


        :param remote_data_volume_type: The remote_data_volume_type of this InstanceConfigurationLaunchOptions.
        :type: str
        """
        allowed_values = ["ISCSI", "SCSI", "IDE", "VFIO", "PARAVIRTUALIZED"]
        if not value_allowed_none_or_none_sentinel(remote_data_volume_type, allowed_values):
            remote_data_volume_type = 'UNKNOWN_ENUM_VALUE'
        self._remote_data_volume_type = remote_data_volume_type

    @property
    def is_pv_encryption_in_transit_enabled(self):
        """
        Gets the is_pv_encryption_in_transit_enabled of this InstanceConfigurationLaunchOptions.
        Deprecated. Instead use `isPvEncryptionInTransitEnabled` in
        :func:`instance_configuration_launch_instance_details`.


        :return: The is_pv_encryption_in_transit_enabled of this InstanceConfigurationLaunchOptions.
        :rtype: bool
        """
        return self._is_pv_encryption_in_transit_enabled

    @is_pv_encryption_in_transit_enabled.setter
    def is_pv_encryption_in_transit_enabled(self, is_pv_encryption_in_transit_enabled):
        """
        Sets the is_pv_encryption_in_transit_enabled of this InstanceConfigurationLaunchOptions.
        Deprecated. Instead use `isPvEncryptionInTransitEnabled` in
        :func:`instance_configuration_launch_instance_details`.


        :param is_pv_encryption_in_transit_enabled: The is_pv_encryption_in_transit_enabled of this InstanceConfigurationLaunchOptions.
        :type: bool
        """
        self._is_pv_encryption_in_transit_enabled = is_pv_encryption_in_transit_enabled

    @property
    def is_consistent_volume_naming_enabled(self):
        """
        Gets the is_consistent_volume_naming_enabled of this InstanceConfigurationLaunchOptions.
        Whether to enable consistent volume naming feature. Defaults to false.


        :return: The is_consistent_volume_naming_enabled of this InstanceConfigurationLaunchOptions.
        :rtype: bool
        """
        return self._is_consistent_volume_naming_enabled

    @is_consistent_volume_naming_enabled.setter
    def is_consistent_volume_naming_enabled(self, is_consistent_volume_naming_enabled):
        """
        Sets the is_consistent_volume_naming_enabled of this InstanceConfigurationLaunchOptions.
        Whether to enable consistent volume naming feature. Defaults to false.


        :param is_consistent_volume_naming_enabled: The is_consistent_volume_naming_enabled of this InstanceConfigurationLaunchOptions.
        :type: bool
        """
        self._is_consistent_volume_naming_enabled = is_consistent_volume_naming_enabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .typed_object import TypedObject
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class OutputPort(TypedObject):
    """
    The output port details.
    """

    #: A constant which can be used with the port_type property of a OutputPort.
    #: This constant has a value of "DATA"
    PORT_TYPE_DATA = "DATA"

    #: A constant which can be used with the port_type property of a OutputPort.
    #: This constant has a value of "CONTROL"
    PORT_TYPE_CONTROL = "CONTROL"

    #: A constant which can be used with the port_type property of a OutputPort.
    #: This constant has a value of "MODEL"
    PORT_TYPE_MODEL = "MODEL"

    def __init__(self, **kwargs):
        """
        Initializes a new OutputPort object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.OutputPort.model_type` attribute
        of this class is ``OUTPUT_PORT`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this OutputPort.
            Allowed values for this property are: "SHAPE", "INPUT_PORT", "SHAPE_FIELD", "INPUT_FIELD", "DERIVED_FIELD", "OUTPUT_FIELD", "DYNAMIC_PROXY_FIELD", "OUTPUT_PORT", "DYNAMIC_INPUT_FIELD", "PROXY_FIELD", "PARAMETER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param key:
            The value to assign to the key property of this OutputPort.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this OutputPort.
        :type model_version: str

        :param parent_ref:
            The value to assign to the parent_ref property of this OutputPort.
        :type parent_ref: ParentReference

        :param config_values:
            The value to assign to the config_values property of this OutputPort.
        :type config_values: ConfigValues

        :param object_status:
            The value to assign to the object_status property of this OutputPort.
        :type object_status: int

        :param name:
            The value to assign to the name property of this OutputPort.
        :type name: str

        :param description:
            The value to assign to the description property of this OutputPort.
        :type description: str

        :param port_type:
            The value to assign to the port_type property of this OutputPort.
            Allowed values for this property are: "DATA", "CONTROL", "MODEL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type port_type: str

        :param fields:
            The value to assign to the fields property of this OutputPort.
        :type fields: list[TypedObject]

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'parent_ref': 'ParentReference',
            'config_values': 'ConfigValues',
            'object_status': 'int',
            'name': 'str',
            'description': 'str',
            'port_type': 'str',
            'fields': 'list[TypedObject]'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'parent_ref': 'parentRef',
            'config_values': 'configValues',
            'object_status': 'objectStatus',
            'name': 'name',
            'description': 'description',
            'port_type': 'portType',
            'fields': 'fields'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._parent_ref = None
        self._config_values = None
        self._object_status = None
        self._name = None
        self._description = None
        self._port_type = None
        self._fields = None
        self._model_type = 'OUTPUT_PORT'

    @property
    def port_type(self):
        """
        Gets the port_type of this OutputPort.
        The port details for the data asset.Type

        Allowed values for this property are: "DATA", "CONTROL", "MODEL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The port_type of this OutputPort.
        :rtype: str
        """
        return self._port_type

    @port_type.setter
    def port_type(self, port_type):
        """
        Sets the port_type of this OutputPort.
        The port details for the data asset.Type


        :param port_type: The port_type of this OutputPort.
        :type: str
        """
        allowed_values = ["DATA", "CONTROL", "MODEL"]
        if not value_allowed_none_or_none_sentinel(port_type, allowed_values):
            port_type = 'UNKNOWN_ENUM_VALUE'
        self._port_type = port_type

    @property
    def fields(self):
        """
        Gets the fields of this OutputPort.
        fields


        :return: The fields of this OutputPort.
        :rtype: list[TypedObject]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """
        Sets the fields of this OutputPort.
        fields


        :param fields: The fields of this OutputPort.
        :type: list[TypedObject]
        """
        self._fields = fields

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Routing(object):
    """
    The routing information for a vantage point.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Routing object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param as_label:
            The value to assign to the as_label property of this Routing.
        :type as_label: str

        :param asn:
            The value to assign to the asn property of this Routing.
        :type asn: int

        :param prefix:
            The value to assign to the prefix property of this Routing.
        :type prefix: str

        :param weight:
            The value to assign to the weight property of this Routing.
        :type weight: int

        """
        self.swagger_types = {
            'as_label': 'str',
            'asn': 'int',
            'prefix': 'str',
            'weight': 'int'
        }

        self.attribute_map = {
            'as_label': 'asLabel',
            'asn': 'asn',
            'prefix': 'prefix',
            'weight': 'weight'
        }

        self._as_label = None
        self._asn = None
        self._prefix = None
        self._weight = None

    @property
    def as_label(self):
        """
        Gets the as_label of this Routing.
        The registry label for `asn`, usually the name of the organization that
        owns the ASN. May be omitted or null.


        :return: The as_label of this Routing.
        :rtype: str
        """
        return self._as_label

    @as_label.setter
    def as_label(self, as_label):
        """
        Sets the as_label of this Routing.
        The registry label for `asn`, usually the name of the organization that
        owns the ASN. May be omitted or null.


        :param as_label: The as_label of this Routing.
        :type: str
        """
        self._as_label = as_label

    @property
    def asn(self):
        """
        Gets the asn of this Routing.
        The Autonomous System Number (ASN) identifying the organization
        responsible for routing packets to `prefix`.


        :return: The asn of this Routing.
        :rtype: int
        """
        return self._asn

    @asn.setter
    def asn(self, asn):
        """
        Sets the asn of this Routing.
        The Autonomous System Number (ASN) identifying the organization
        responsible for routing packets to `prefix`.


        :param asn: The asn of this Routing.
        :type: int
        """
        self._asn = asn

    @property
    def prefix(self):
        """
        Gets the prefix of this Routing.
        An IP prefix (CIDR syntax) that is less specific than
        `address`, through which `address` is routed.


        :return: The prefix of this Routing.
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """
        Sets the prefix of this Routing.
        An IP prefix (CIDR syntax) that is less specific than
        `address`, through which `address` is routed.


        :param prefix: The prefix of this Routing.
        :type: str
        """
        self._prefix = prefix

    @property
    def weight(self):
        """
        Gets the weight of this Routing.
        An integer between 0 and 100 used to select between multiple
        origin ASNs when routing to `prefix`. Most prefixes have
        exactly one origin ASN, in which case `weight` will be 100.


        :return: The weight of this Routing.
        :rtype: int
        """
        return self._weight

    @weight.setter
    def weight(self, weight):
        """
        Sets the weight of this Routing.
        An integer between 0 and 100 used to select between multiple
        origin ASNs when routing to `prefix`. Most prefixes have
        exactly one origin ASN, in which case `weight` will be 100.


        :param weight: The weight of this Routing.
        :type: int
        """
        self._weight = weight

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDatabaseSoftwareImageDetails(object):
    """
    Parameters for creating a database software image in the specified compartment.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    #: A constant which can be used with the image_shape_family property of a CreateDatabaseSoftwareImageDetails.
    #: This constant has a value of "VM_BM_SHAPE"
    IMAGE_SHAPE_FAMILY_VM_BM_SHAPE = "VM_BM_SHAPE"

    #: A constant which can be used with the image_shape_family property of a CreateDatabaseSoftwareImageDetails.
    #: This constant has a value of "EXADATA_SHAPE"
    IMAGE_SHAPE_FAMILY_EXADATA_SHAPE = "EXADATA_SHAPE"

    #: A constant which can be used with the image_type property of a CreateDatabaseSoftwareImageDetails.
    #: This constant has a value of "GRID_IMAGE"
    IMAGE_TYPE_GRID_IMAGE = "GRID_IMAGE"

    #: A constant which can be used with the image_type property of a CreateDatabaseSoftwareImageDetails.
    #: This constant has a value of "DATABASE_IMAGE"
    IMAGE_TYPE_DATABASE_IMAGE = "DATABASE_IMAGE"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDatabaseSoftwareImageDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateDatabaseSoftwareImageDetails.
        :type compartment_id: str

        :param database_version:
            The value to assign to the database_version property of this CreateDatabaseSoftwareImageDetails.
        :type database_version: str

        :param display_name:
            The value to assign to the display_name property of this CreateDatabaseSoftwareImageDetails.
        :type display_name: str

        :param image_shape_family:
            The value to assign to the image_shape_family property of this CreateDatabaseSoftwareImageDetails.
            Allowed values for this property are: "VM_BM_SHAPE", "EXADATA_SHAPE"
        :type image_shape_family: str

        :param image_type:
            The value to assign to the image_type property of this CreateDatabaseSoftwareImageDetails.
            Allowed values for this property are: "GRID_IMAGE", "DATABASE_IMAGE"
        :type image_type: str

        :param patch_set:
            The value to assign to the patch_set property of this CreateDatabaseSoftwareImageDetails.
        :type patch_set: str

        :param database_software_image_one_off_patches:
            The value to assign to the database_software_image_one_off_patches property of this CreateDatabaseSoftwareImageDetails.
        :type database_software_image_one_off_patches: list[str]

        :param ls_inventory:
            The value to assign to the ls_inventory property of this CreateDatabaseSoftwareImageDetails.
        :type ls_inventory: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateDatabaseSoftwareImageDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateDatabaseSoftwareImageDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'database_version': 'str',
            'display_name': 'str',
            'image_shape_family': 'str',
            'image_type': 'str',
            'patch_set': 'str',
            'database_software_image_one_off_patches': 'list[str]',
            'ls_inventory': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'database_version': 'databaseVersion',
            'display_name': 'displayName',
            'image_shape_family': 'imageShapeFamily',
            'image_type': 'imageType',
            'patch_set': 'patchSet',
            'database_software_image_one_off_patches': 'databaseSoftwareImageOneOffPatches',
            'ls_inventory': 'lsInventory',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._compartment_id = None
        self._database_version = None
        self._display_name = None
        self._image_shape_family = None
        self._image_type = None
        self._patch_set = None
        self._database_software_image_one_off_patches = None
        self._ls_inventory = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateDatabaseSoftwareImageDetails.
        The `OCID`__ of the compartment the database software image  belongs in.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateDatabaseSoftwareImageDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateDatabaseSoftwareImageDetails.
        The `OCID`__ of the compartment the database software image  belongs in.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateDatabaseSoftwareImageDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def database_version(self):
        """
        **[Required]** Gets the database_version of this CreateDatabaseSoftwareImageDetails.
        The database version with which the database software image is to be built.


        :return: The database_version of this CreateDatabaseSoftwareImageDetails.
        :rtype: str
        """
        return self._database_version

    @database_version.setter
    def database_version(self, database_version):
        """
        Sets the database_version of this CreateDatabaseSoftwareImageDetails.
        The database version with which the database software image is to be built.


        :param database_version: The database_version of this CreateDatabaseSoftwareImageDetails.
        :type: str
        """
        self._database_version = database_version

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateDatabaseSoftwareImageDetails.
        The user-friendly name for the database software image. The name does not have to be unique.


        :return: The display_name of this CreateDatabaseSoftwareImageDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateDatabaseSoftwareImageDetails.
        The user-friendly name for the database software image. The name does not have to be unique.


        :param display_name: The display_name of this CreateDatabaseSoftwareImageDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def image_shape_family(self):
        """
        Gets the image_shape_family of this CreateDatabaseSoftwareImageDetails.
        To what shape the image is meant for.

        Allowed values for this property are: "VM_BM_SHAPE", "EXADATA_SHAPE"


        :return: The image_shape_family of this CreateDatabaseSoftwareImageDetails.
        :rtype: str
        """
        return self._image_shape_family

    @image_shape_family.setter
    def image_shape_family(self, image_shape_family):
        """
        Sets the image_shape_family of this CreateDatabaseSoftwareImageDetails.
        To what shape the image is meant for.


        :param image_shape_family: The image_shape_family of this CreateDatabaseSoftwareImageDetails.
        :type: str
        """
        allowed_values = ["VM_BM_SHAPE", "EXADATA_SHAPE"]
        if not value_allowed_none_or_none_sentinel(image_shape_family, allowed_values):
            raise ValueError(
                "Invalid value for `image_shape_family`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._image_shape_family = image_shape_family

    @property
    def image_type(self):
        """
        Gets the image_type of this CreateDatabaseSoftwareImageDetails.
        List of the Fault Domains in which this DB system is provisioned.

        Allowed values for this property are: "GRID_IMAGE", "DATABASE_IMAGE"


        :return: The image_type of this CreateDatabaseSoftwareImageDetails.
        :rtype: str
        """
        return self._image_type

    @image_type.setter
    def image_type(self, image_type):
        """
        Sets the image_type of this CreateDatabaseSoftwareImageDetails.
        List of the Fault Domains in which this DB system is provisioned.


        :param image_type: The image_type of this CreateDatabaseSoftwareImageDetails.
        :type: str
        """
        allowed_values = ["GRID_IMAGE", "DATABASE_IMAGE"]
        if not value_allowed_none_or_none_sentinel(image_type, allowed_values):
            raise ValueError(
                "Invalid value for `image_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._image_type = image_type

    @property
    def patch_set(self):
        """
        **[Required]** Gets the patch_set of this CreateDatabaseSoftwareImageDetails.
        The PSU or PBP or Release Updates. To get a list of supported versions, use the :func:`list_db_versions` operation.


        :return: The patch_set of this CreateDatabaseSoftwareImageDetails.
        :rtype: str
        """
        return self._patch_set

    @patch_set.setter
    def patch_set(self, patch_set):
        """
        Sets the patch_set of this CreateDatabaseSoftwareImageDetails.
        The PSU or PBP or Release Updates. To get a list of supported versions, use the :func:`list_db_versions` operation.


        :param patch_set: The patch_set of this CreateDatabaseSoftwareImageDetails.
        :type: str
        """
        self._patch_set = patch_set

    @property
    def database_software_image_one_off_patches(self):
        """
        Gets the database_software_image_one_off_patches of this CreateDatabaseSoftwareImageDetails.
        List of one-off patches for Database Homes.


        :return: The database_software_image_one_off_patches of this CreateDatabaseSoftwareImageDetails.
        :rtype: list[str]
        """
        return self._database_software_image_one_off_patches

    @database_software_image_one_off_patches.setter
    def database_software_image_one_off_patches(self, database_software_image_one_off_patches):
        """
        Sets the database_software_image_one_off_patches of this CreateDatabaseSoftwareImageDetails.
        List of one-off patches for Database Homes.


        :param database_software_image_one_off_patches: The database_software_image_one_off_patches of this CreateDatabaseSoftwareImageDetails.
        :type: list[str]
        """
        self._database_software_image_one_off_patches = database_software_image_one_off_patches

    @property
    def ls_inventory(self):
        """
        Gets the ls_inventory of this CreateDatabaseSoftwareImageDetails.
        output from lsinventory which will get passed as a string


        :return: The ls_inventory of this CreateDatabaseSoftwareImageDetails.
        :rtype: str
        """
        return self._ls_inventory

    @ls_inventory.setter
    def ls_inventory(self, ls_inventory):
        """
        Sets the ls_inventory of this CreateDatabaseSoftwareImageDetails.
        output from lsinventory which will get passed as a string


        :param ls_inventory: The ls_inventory of this CreateDatabaseSoftwareImageDetails.
        :type: str
        """
        self._ls_inventory = ls_inventory

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateDatabaseSoftwareImageDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateDatabaseSoftwareImageDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateDatabaseSoftwareImageDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateDatabaseSoftwareImageDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateDatabaseSoftwareImageDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateDatabaseSoftwareImageDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateDatabaseSoftwareImageDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateDatabaseSoftwareImageDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateAlarmDetails(object):
    """
    The configuration details for creating an alarm.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateAlarmDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateAlarmDetails.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateAlarmDetails.
        :type compartment_id: str

        :param metric_compartment_id:
            The value to assign to the metric_compartment_id property of this CreateAlarmDetails.
        :type metric_compartment_id: str

        :param metric_compartment_id_in_subtree:
            The value to assign to the metric_compartment_id_in_subtree property of this CreateAlarmDetails.
        :type metric_compartment_id_in_subtree: bool

        :param namespace:
            The value to assign to the namespace property of this CreateAlarmDetails.
        :type namespace: str

        :param resource_group:
            The value to assign to the resource_group property of this CreateAlarmDetails.
        :type resource_group: str

        :param query:
            The value to assign to the query property of this CreateAlarmDetails.
        :type query: str

        :param resolution:
            The value to assign to the resolution property of this CreateAlarmDetails.
        :type resolution: str

        :param pending_duration:
            The value to assign to the pending_duration property of this CreateAlarmDetails.
        :type pending_duration: str

        :param severity:
            The value to assign to the severity property of this CreateAlarmDetails.
        :type severity: str

        :param body:
            The value to assign to the body property of this CreateAlarmDetails.
        :type body: str

        :param destinations:
            The value to assign to the destinations property of this CreateAlarmDetails.
        :type destinations: list[str]

        :param repeat_notification_duration:
            The value to assign to the repeat_notification_duration property of this CreateAlarmDetails.
        :type repeat_notification_duration: str

        :param suppression:
            The value to assign to the suppression property of this CreateAlarmDetails.
        :type suppression: Suppression

        :param is_enabled:
            The value to assign to the is_enabled property of this CreateAlarmDetails.
        :type is_enabled: bool

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateAlarmDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateAlarmDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'compartment_id': 'str',
            'metric_compartment_id': 'str',
            'metric_compartment_id_in_subtree': 'bool',
            'namespace': 'str',
            'resource_group': 'str',
            'query': 'str',
            'resolution': 'str',
            'pending_duration': 'str',
            'severity': 'str',
            'body': 'str',
            'destinations': 'list[str]',
            'repeat_notification_duration': 'str',
            'suppression': 'Suppression',
            'is_enabled': 'bool',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'metric_compartment_id': 'metricCompartmentId',
            'metric_compartment_id_in_subtree': 'metricCompartmentIdInSubtree',
            'namespace': 'namespace',
            'resource_group': 'resourceGroup',
            'query': 'query',
            'resolution': 'resolution',
            'pending_duration': 'pendingDuration',
            'severity': 'severity',
            'body': 'body',
            'destinations': 'destinations',
            'repeat_notification_duration': 'repeatNotificationDuration',
            'suppression': 'suppression',
            'is_enabled': 'isEnabled',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._compartment_id = None
        self._metric_compartment_id = None
        self._metric_compartment_id_in_subtree = None
        self._namespace = None
        self._resource_group = None
        self._query = None
        self._resolution = None
        self._pending_duration = None
        self._severity = None
        self._body = None
        self._destinations = None
        self._repeat_notification_duration = None
        self._suppression = None
        self._is_enabled = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateAlarmDetails.
        A user-friendly name for the alarm. It does not have to be unique, and it's changeable.
        Avoid entering confidential information.

        This name is sent as the title for notifications related to this alarm.

        Example: `High CPU Utilization`


        :return: The display_name of this CreateAlarmDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateAlarmDetails.
        A user-friendly name for the alarm. It does not have to be unique, and it's changeable.
        Avoid entering confidential information.

        This name is sent as the title for notifications related to this alarm.

        Example: `High CPU Utilization`


        :param display_name: The display_name of this CreateAlarmDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateAlarmDetails.
        The `OCID`__ of the compartment containing the alarm.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateAlarmDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateAlarmDetails.
        The `OCID`__ of the compartment containing the alarm.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateAlarmDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def metric_compartment_id(self):
        """
        **[Required]** Gets the metric_compartment_id of this CreateAlarmDetails.
        The `OCID`__ of the compartment containing the metric
        being evaluated by the alarm.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The metric_compartment_id of this CreateAlarmDetails.
        :rtype: str
        """
        return self._metric_compartment_id

    @metric_compartment_id.setter
    def metric_compartment_id(self, metric_compartment_id):
        """
        Sets the metric_compartment_id of this CreateAlarmDetails.
        The `OCID`__ of the compartment containing the metric
        being evaluated by the alarm.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param metric_compartment_id: The metric_compartment_id of this CreateAlarmDetails.
        :type: str
        """
        self._metric_compartment_id = metric_compartment_id

    @property
    def metric_compartment_id_in_subtree(self):
        """
        Gets the metric_compartment_id_in_subtree of this CreateAlarmDetails.
        When true, the alarm evaluates metrics from all compartments and subcompartments. The parameter can
        only be set to true when metricCompartmentId is the tenancy OCID (the tenancy is the root compartment).
        A true value requires the user to have tenancy-level permissions. If this requirement is not met,
        then the call is rejected. When false, the alarm evaluates metrics from only the compartment specified
        in metricCompartmentId. Default is false.

        Example: `true`


        :return: The metric_compartment_id_in_subtree of this CreateAlarmDetails.
        :rtype: bool
        """
        return self._metric_compartment_id_in_subtree

    @metric_compartment_id_in_subtree.setter
    def metric_compartment_id_in_subtree(self, metric_compartment_id_in_subtree):
        """
        Sets the metric_compartment_id_in_subtree of this CreateAlarmDetails.
        When true, the alarm evaluates metrics from all compartments and subcompartments. The parameter can
        only be set to true when metricCompartmentId is the tenancy OCID (the tenancy is the root compartment).
        A true value requires the user to have tenancy-level permissions. If this requirement is not met,
        then the call is rejected. When false, the alarm evaluates metrics from only the compartment specified
        in metricCompartmentId. Default is false.

        Example: `true`


        :param metric_compartment_id_in_subtree: The metric_compartment_id_in_subtree of this CreateAlarmDetails.
        :type: bool
        """
        self._metric_compartment_id_in_subtree = metric_compartment_id_in_subtree

    @property
    def namespace(self):
        """
        **[Required]** Gets the namespace of this CreateAlarmDetails.
        The source service or application emitting the metric that is evaluated by the alarm.

        Example: `oci_computeagent`


        :return: The namespace of this CreateAlarmDetails.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this CreateAlarmDetails.
        The source service or application emitting the metric that is evaluated by the alarm.

        Example: `oci_computeagent`


        :param namespace: The namespace of this CreateAlarmDetails.
        :type: str
        """
        self._namespace = namespace

    @property
    def resource_group(self):
        """
        Gets the resource_group of this CreateAlarmDetails.
        Resource group that you want to use as a filter. The alarm retrieves metric data associated with the specified resource group only. Only one resource group can be applied per metric.
        A valid resourceGroup value starts with an alphabetical character and includes only alphanumeric characters, periods (.), underscores (_), hyphens (-), and dollar signs ($).
        Avoid entering confidential information.

        Example: `frontend-fleet`


        :return: The resource_group of this CreateAlarmDetails.
        :rtype: str
        """
        return self._resource_group

    @resource_group.setter
    def resource_group(self, resource_group):
        """
        Sets the resource_group of this CreateAlarmDetails.
        Resource group that you want to use as a filter. The alarm retrieves metric data associated with the specified resource group only. Only one resource group can be applied per metric.
        A valid resourceGroup value starts with an alphabetical character and includes only alphanumeric characters, periods (.), underscores (_), hyphens (-), and dollar signs ($).
        Avoid entering confidential information.

        Example: `frontend-fleet`


        :param resource_group: The resource_group of this CreateAlarmDetails.
        :type: str
        """
        self._resource_group = resource_group

    @property
    def query(self):
        """
        **[Required]** Gets the query of this CreateAlarmDetails.
        The Monitoring Query Language (MQL) expression to evaluate for the alarm. The Alarms feature of
        the Monitoring service interprets results for each returned time series as Boolean values,
        where zero represents false and a non-zero value represents true. A true value means that the trigger
        rule condition has been met. The query must specify a metric, statistic, interval, and trigger
        rule (threshold or absence). Supported values for interval: `1m`-`60m` (also `1h`). You can optionally
        specify dimensions and grouping functions. Supported grouping functions: `grouping()`, `groupBy()`.
        For details about Monitoring Query Language (MQL), see `Monitoring Query Language (MQL) Reference`__.
        For available dimensions, review the metric definition for the supported service.
        See `Supported Services`__.

        Example of threshold alarm:

          -----

            CpuUtilization[1m]{availabilityDomain=\"cumS:PHX-AD-1\"}.groupBy(availabilityDomain).percentile(0.9) > 85

          -----

        Example of absence alarm:

          -----

            CpuUtilization[1m]{availabilityDomain=\"cumS:PHX-AD-1\"}.absent()

          -----

        __ https://docs.cloud.oracle.com/iaas/Content/Monitoring/Reference/mql.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#SupportedServices


        :return: The query of this CreateAlarmDetails.
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """
        Sets the query of this CreateAlarmDetails.
        The Monitoring Query Language (MQL) expression to evaluate for the alarm. The Alarms feature of
        the Monitoring service interprets results for each returned time series as Boolean values,
        where zero represents false and a non-zero value represents true. A true value means that the trigger
        rule condition has been met. The query must specify a metric, statistic, interval, and trigger
        rule (threshold or absence). Supported values for interval: `1m`-`60m` (also `1h`). You can optionally
        specify dimensions and grouping functions. Supported grouping functions: `grouping()`, `groupBy()`.
        For details about Monitoring Query Language (MQL), see `Monitoring Query Language (MQL) Reference`__.
        For available dimensions, review the metric definition for the supported service.
        See `Supported Services`__.

        Example of threshold alarm:

          -----

            CpuUtilization[1m]{availabilityDomain=\"cumS:PHX-AD-1\"}.groupBy(availabilityDomain).percentile(0.9) > 85

          -----

        Example of absence alarm:

          -----

            CpuUtilization[1m]{availabilityDomain=\"cumS:PHX-AD-1\"}.absent()

          -----

        __ https://docs.cloud.oracle.com/iaas/Content/Monitoring/Reference/mql.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Monitoring/Concepts/monitoringoverview.htm#SupportedServices


        :param query: The query of this CreateAlarmDetails.
        :type: str
        """
        self._query = query

    @property
    def resolution(self):
        """
        Gets the resolution of this CreateAlarmDetails.
        The time between calculated aggregation windows for the alarm. Supported value: `1m`


        :return: The resolution of this CreateAlarmDetails.
        :rtype: str
        """
        return self._resolution

    @resolution.setter
    def resolution(self, resolution):
        """
        Sets the resolution of this CreateAlarmDetails.
        The time between calculated aggregation windows for the alarm. Supported value: `1m`


        :param resolution: The resolution of this CreateAlarmDetails.
        :type: str
        """
        self._resolution = resolution

    @property
    def pending_duration(self):
        """
        Gets the pending_duration of this CreateAlarmDetails.
        The period of time that the condition defined in the alarm must persist before the alarm state
        changes from \"OK\" to \"FIRING\". For example, a value of 5 minutes means that the
        alarm must persist in breaching the condition for five minutes before the alarm updates its
        state to \"FIRING\".

        The duration is specified as a string in ISO 8601 format (`PT10M` for ten minutes or `PT1H`
        for one hour). Minimum: PT1M. Maximum: PT1H. Default: PT1M.

        Under the default value of PT1M, the first evaluation that breaches the alarm updates the
        state to \"FIRING\".

        The alarm updates its status to \"OK\" when the breaching condition has been clear for
        the most recent minute.

        Example: `PT5M`


        :return: The pending_duration of this CreateAlarmDetails.
        :rtype: str
        """
        return self._pending_duration

    @pending_duration.setter
    def pending_duration(self, pending_duration):
        """
        Sets the pending_duration of this CreateAlarmDetails.
        The period of time that the condition defined in the alarm must persist before the alarm state
        changes from \"OK\" to \"FIRING\". For example, a value of 5 minutes means that the
        alarm must persist in breaching the condition for five minutes before the alarm updates its
        state to \"FIRING\".

        The duration is specified as a string in ISO 8601 format (`PT10M` for ten minutes or `PT1H`
        for one hour). Minimum: PT1M. Maximum: PT1H. Default: PT1M.

        Under the default value of PT1M, the first evaluation that breaches the alarm updates the
        state to \"FIRING\".

        The alarm updates its status to \"OK\" when the breaching condition has been clear for
        the most recent minute.

        Example: `PT5M`


        :param pending_duration: The pending_duration of this CreateAlarmDetails.
        :type: str
        """
        self._pending_duration = pending_duration

    @property
    def severity(self):
        """
        **[Required]** Gets the severity of this CreateAlarmDetails.
        The perceived type of response required when the alarm is in the \"FIRING\" state.

        Example: `CRITICAL`


        :return: The severity of this CreateAlarmDetails.
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """
        Sets the severity of this CreateAlarmDetails.
        The perceived type of response required when the alarm is in the \"FIRING\" state.

        Example: `CRITICAL`


        :param severity: The severity of this CreateAlarmDetails.
        :type: str
        """
        self._severity = severity

    @property
    def body(self):
        """
        Gets the body of this CreateAlarmDetails.
        The human-readable content of the notification delivered. Oracle recommends providing guidance
        to operators for resolving the alarm condition. Consider adding links to standard runbook
        practices. Avoid entering confidential information.

        Example: `High CPU usage alert. Follow runbook instructions for resolution.`


        :return: The body of this CreateAlarmDetails.
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """
        Sets the body of this CreateAlarmDetails.
        The human-readable content of the notification delivered. Oracle recommends providing guidance
        to operators for resolving the alarm condition. Consider adding links to standard runbook
        practices. Avoid entering confidential information.

        Example: `High CPU usage alert. Follow runbook instructions for resolution.`


        :param body: The body of this CreateAlarmDetails.
        :type: str
        """
        self._body = body

    @property
    def destinations(self):
        """
        **[Required]** Gets the destinations of this CreateAlarmDetails.
        A list of destinations to which the notifications for this alarm will be delivered.
        Each destination is represented by an `OCID`__ related to the supported destination service.
        For example, a destination using the Notifications service is represented by a topic OCID.
        Supported destination services: Notifications Service. Limit: One destination per supported destination service.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The destinations of this CreateAlarmDetails.
        :rtype: list[str]
        """
        return self._destinations

    @destinations.setter
    def destinations(self, destinations):
        """
        Sets the destinations of this CreateAlarmDetails.
        A list of destinations to which the notifications for this alarm will be delivered.
        Each destination is represented by an `OCID`__ related to the supported destination service.
        For example, a destination using the Notifications service is represented by a topic OCID.
        Supported destination services: Notifications Service. Limit: One destination per supported destination service.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param destinations: The destinations of this CreateAlarmDetails.
        :type: list[str]
        """
        self._destinations = destinations

    @property
    def repeat_notification_duration(self):
        """
        Gets the repeat_notification_duration of this CreateAlarmDetails.
        The frequency at which notifications are re-submitted, if the alarm keeps firing without
        interruption. Format defined by ISO 8601. For example, `PT4H` indicates four hours.
        Minimum: PT1M. Maximum: P30D.

        Default value: null (notifications are not re-submitted).

        Example: `PT2H`


        :return: The repeat_notification_duration of this CreateAlarmDetails.
        :rtype: str
        """
        return self._repeat_notification_duration

    @repeat_notification_duration.setter
    def repeat_notification_duration(self, repeat_notification_duration):
        """
        Sets the repeat_notification_duration of this CreateAlarmDetails.
        The frequency at which notifications are re-submitted, if the alarm keeps firing without
        interruption. Format defined by ISO 8601. For example, `PT4H` indicates four hours.
        Minimum: PT1M. Maximum: P30D.

        Default value: null (notifications are not re-submitted).

        Example: `PT2H`


        :param repeat_notification_duration: The repeat_notification_duration of this CreateAlarmDetails.
        :type: str
        """
        self._repeat_notification_duration = repeat_notification_duration

    @property
    def suppression(self):
        """
        Gets the suppression of this CreateAlarmDetails.
        The configuration details for suppressing an alarm.


        :return: The suppression of this CreateAlarmDetails.
        :rtype: Suppression
        """
        return self._suppression

    @suppression.setter
    def suppression(self, suppression):
        """
        Sets the suppression of this CreateAlarmDetails.
        The configuration details for suppressing an alarm.


        :param suppression: The suppression of this CreateAlarmDetails.
        :type: Suppression
        """
        self._suppression = suppression

    @property
    def is_enabled(self):
        """
        **[Required]** Gets the is_enabled of this CreateAlarmDetails.
        Whether the alarm is enabled.

        Example: `true`


        :return: The is_enabled of this CreateAlarmDetails.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this CreateAlarmDetails.
        Whether the alarm is enabled.

        Example: `true`


        :param is_enabled: The is_enabled of this CreateAlarmDetails.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateAlarmDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"Department\": \"Finance\"}`


        :return: The freeform_tags of this CreateAlarmDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateAlarmDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"Department\": \"Finance\"}`


        :param freeform_tags: The freeform_tags of this CreateAlarmDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateAlarmDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`


        :return: The defined_tags of this CreateAlarmDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateAlarmDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`


        :param defined_tags: The defined_tags of this CreateAlarmDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .access_log_policy import AccessLogPolicy
from .anonymous_route_authorization_policy import AnonymousRouteAuthorizationPolicy
from .any_of_route_authorization_policy import AnyOfRouteAuthorizationPolicy
from .api_specification import ApiSpecification
from .api_specification_logging_policies import ApiSpecificationLoggingPolicies
from .api_specification_request_policies import ApiSpecificationRequestPolicies
from .api_specification_route import ApiSpecificationRoute
from .api_specification_route_backend import ApiSpecificationRouteBackend
from .api_specification_route_request_policies import ApiSpecificationRouteRequestPolicies
from .api_specification_route_response_policies import ApiSpecificationRouteResponsePolicies
from .authentication_only_route_authorization_policy import AuthenticationOnlyRouteAuthorizationPolicy
from .authentication_policy import AuthenticationPolicy
from .certificate import Certificate
from .certificate_collection import CertificateCollection
from .certificate_summary import CertificateSummary
from .change_certificate_compartment_details import ChangeCertificateCompartmentDetails
from .change_deployment_compartment_details import ChangeDeploymentCompartmentDetails
from .change_gateway_compartment_details import ChangeGatewayCompartmentDetails
from .cors_policy import CorsPolicy
from .create_certificate_details import CreateCertificateDetails
from .create_deployment_details import CreateDeploymentDetails
from .create_gateway_details import CreateGatewayDetails
from .custom_authentication_policy import CustomAuthenticationPolicy
from .deployment import Deployment
from .deployment_collection import DeploymentCollection
from .deployment_summary import DeploymentSummary
from .execution_log_policy import ExecutionLogPolicy
from .filter_header_policy import FilterHeaderPolicy
from .filter_header_policy_item import FilterHeaderPolicyItem
from .filter_query_parameter_policy import FilterQueryParameterPolicy
from .filter_query_parameter_policy_item import FilterQueryParameterPolicyItem
from .gateway import Gateway
from .gateway_collection import GatewayCollection
from .gateway_summary import GatewaySummary
from .http_backend import HTTPBackend
from .header_field_specification import HeaderFieldSpecification
from .header_transformation_policy import HeaderTransformationPolicy
from .ip_address import IpAddress
from .json_web_key import JsonWebKey
from .json_web_token_claim import JsonWebTokenClaim
from .jwt_authentication_policy import JwtAuthenticationPolicy
from .oracle_function_backend import OracleFunctionBackend
from .pem_encoded_public_key import PemEncodedPublicKey
from .public_key_set import PublicKeySet
from .query_parameter_transformation_policy import QueryParameterTransformationPolicy
from .rate_limiting_policy import RateLimitingPolicy
from .remote_json_web_key_set import RemoteJsonWebKeySet
from .rename_header_policy import RenameHeaderPolicy
from .rename_header_policy_item import RenameHeaderPolicyItem
from .rename_query_parameter_policy import RenameQueryParameterPolicy
from .rename_query_parameter_policy_item import RenameQueryParameterPolicyItem
from .route_authorization_policy import RouteAuthorizationPolicy
from .set_header_policy import SetHeaderPolicy
from .set_header_policy_item import SetHeaderPolicyItem
from .set_query_parameter_policy import SetQueryParameterPolicy
from .set_query_parameter_policy_item import SetQueryParameterPolicyItem
from .static_public_key import StaticPublicKey
from .static_public_key_set import StaticPublicKeySet
from .stock_response_backend import StockResponseBackend
from .update_certificate_details import UpdateCertificateDetails
from .update_deployment_details import UpdateDeploymentDetails
from .update_gateway_details import UpdateGatewayDetails
from .work_request import WorkRequest
from .work_request_collection import WorkRequestCollection
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log import WorkRequestLog
from .work_request_log_collection import WorkRequestLogCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for apigateway services.
apigateway_type_mapping = {
    "AccessLogPolicy": AccessLogPolicy,
    "AnonymousRouteAuthorizationPolicy": AnonymousRouteAuthorizationPolicy,
    "AnyOfRouteAuthorizationPolicy": AnyOfRouteAuthorizationPolicy,
    "ApiSpecification": ApiSpecification,
    "ApiSpecificationLoggingPolicies": ApiSpecificationLoggingPolicies,
    "ApiSpecificationRequestPolicies": ApiSpecificationRequestPolicies,
    "ApiSpecificationRoute": ApiSpecificationRoute,
    "ApiSpecificationRouteBackend": ApiSpecificationRouteBackend,
    "ApiSpecificationRouteRequestPolicies": ApiSpecificationRouteRequestPolicies,
    "ApiSpecificationRouteResponsePolicies": ApiSpecificationRouteResponsePolicies,
    "AuthenticationOnlyRouteAuthorizationPolicy": AuthenticationOnlyRouteAuthorizationPolicy,
    "AuthenticationPolicy": AuthenticationPolicy,
    "Certificate": Certificate,
    "CertificateCollection": CertificateCollection,
    "CertificateSummary": CertificateSummary,
    "ChangeCertificateCompartmentDetails": ChangeCertificateCompartmentDetails,
    "ChangeDeploymentCompartmentDetails": ChangeDeploymentCompartmentDetails,
    "ChangeGatewayCompartmentDetails": ChangeGatewayCompartmentDetails,
    "CorsPolicy": CorsPolicy,
    "CreateCertificateDetails": CreateCertificateDetails,
    "CreateDeploymentDetails": CreateDeploymentDetails,
    "CreateGatewayDetails": CreateGatewayDetails,
    "CustomAuthenticationPolicy": CustomAuthenticationPolicy,
    "Deployment": Deployment,
    "DeploymentCollection": DeploymentCollection,
    "DeploymentSummary": DeploymentSummary,
    "ExecutionLogPolicy": ExecutionLogPolicy,
    "FilterHeaderPolicy": FilterHeaderPolicy,
    "FilterHeaderPolicyItem": FilterHeaderPolicyItem,
    "FilterQueryParameterPolicy": FilterQueryParameterPolicy,
    "FilterQueryParameterPolicyItem": FilterQueryParameterPolicyItem,
    "Gateway": Gateway,
    "GatewayCollection": GatewayCollection,
    "GatewaySummary": GatewaySummary,
    "HTTPBackend": HTTPBackend,
    "HeaderFieldSpecification": HeaderFieldSpecification,
    "HeaderTransformationPolicy": HeaderTransformationPolicy,
    "IpAddress": IpAddress,
    "JsonWebKey": JsonWebKey,
    "JsonWebTokenClaim": JsonWebTokenClaim,
    "JwtAuthenticationPolicy": JwtAuthenticationPolicy,
    "OracleFunctionBackend": OracleFunctionBackend,
    "PemEncodedPublicKey": PemEncodedPublicKey,
    "PublicKeySet": PublicKeySet,
    "QueryParameterTransformationPolicy": QueryParameterTransformationPolicy,
    "RateLimitingPolicy": RateLimitingPolicy,
    "RemoteJsonWebKeySet": RemoteJsonWebKeySet,
    "RenameHeaderPolicy": RenameHeaderPolicy,
    "RenameHeaderPolicyItem": RenameHeaderPolicyItem,
    "RenameQueryParameterPolicy": RenameQueryParameterPolicy,
    "RenameQueryParameterPolicyItem": RenameQueryParameterPolicyItem,
    "RouteAuthorizationPolicy": RouteAuthorizationPolicy,
    "SetHeaderPolicy": SetHeaderPolicy,
    "SetHeaderPolicyItem": SetHeaderPolicyItem,
    "SetQueryParameterPolicy": SetQueryParameterPolicy,
    "SetQueryParameterPolicyItem": SetQueryParameterPolicyItem,
    "StaticPublicKey": StaticPublicKey,
    "StaticPublicKeySet": StaticPublicKeySet,
    "StockResponseBackend": StockResponseBackend,
    "UpdateCertificateDetails": UpdateCertificateDetails,
    "UpdateDeploymentDetails": UpdateDeploymentDetails,
    "UpdateGatewayDetails": UpdateGatewayDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestCollection": WorkRequestCollection,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLog": WorkRequestLog,
    "WorkRequestLogCollection": WorkRequestLogCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AttachLoadBalancerDetails(object):
    """
    Represents a load balancer that is to be attached to an instance pool.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AttachLoadBalancerDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param load_balancer_id:
            The value to assign to the load_balancer_id property of this AttachLoadBalancerDetails.
        :type load_balancer_id: str

        :param backend_set_name:
            The value to assign to the backend_set_name property of this AttachLoadBalancerDetails.
        :type backend_set_name: str

        :param port:
            The value to assign to the port property of this AttachLoadBalancerDetails.
        :type port: int

        :param vnic_selection:
            The value to assign to the vnic_selection property of this AttachLoadBalancerDetails.
        :type vnic_selection: str

        """
        self.swagger_types = {
            'load_balancer_id': 'str',
            'backend_set_name': 'str',
            'port': 'int',
            'vnic_selection': 'str'
        }

        self.attribute_map = {
            'load_balancer_id': 'loadBalancerId',
            'backend_set_name': 'backendSetName',
            'port': 'port',
            'vnic_selection': 'vnicSelection'
        }

        self._load_balancer_id = None
        self._backend_set_name = None
        self._port = None
        self._vnic_selection = None

    @property
    def load_balancer_id(self):
        """
        **[Required]** Gets the load_balancer_id of this AttachLoadBalancerDetails.
        The `OCID`__ of the load balancer to attach to the instance pool.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The load_balancer_id of this AttachLoadBalancerDetails.
        :rtype: str
        """
        return self._load_balancer_id

    @load_balancer_id.setter
    def load_balancer_id(self, load_balancer_id):
        """
        Sets the load_balancer_id of this AttachLoadBalancerDetails.
        The `OCID`__ of the load balancer to attach to the instance pool.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param load_balancer_id: The load_balancer_id of this AttachLoadBalancerDetails.
        :type: str
        """
        self._load_balancer_id = load_balancer_id

    @property
    def backend_set_name(self):
        """
        **[Required]** Gets the backend_set_name of this AttachLoadBalancerDetails.
        The name of the backend set on the load balancer to add instances to.


        :return: The backend_set_name of this AttachLoadBalancerDetails.
        :rtype: str
        """
        return self._backend_set_name

    @backend_set_name.setter
    def backend_set_name(self, backend_set_name):
        """
        Sets the backend_set_name of this AttachLoadBalancerDetails.
        The name of the backend set on the load balancer to add instances to.


        :param backend_set_name: The backend_set_name of this AttachLoadBalancerDetails.
        :type: str
        """
        self._backend_set_name = backend_set_name

    @property
    def port(self):
        """
        **[Required]** Gets the port of this AttachLoadBalancerDetails.
        The port value to use when creating the backend set.


        :return: The port of this AttachLoadBalancerDetails.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this AttachLoadBalancerDetails.
        The port value to use when creating the backend set.


        :param port: The port of this AttachLoadBalancerDetails.
        :type: int
        """
        self._port = port

    @property
    def vnic_selection(self):
        """
        **[Required]** Gets the vnic_selection of this AttachLoadBalancerDetails.
        Indicates which VNIC on each instance in the pool should be used to associate with the load balancer. Possible values are \"PrimaryVnic\" or the displayName of one of the secondary VNICs on the instance configuration that is associated with the instance pool.


        :return: The vnic_selection of this AttachLoadBalancerDetails.
        :rtype: str
        """
        return self._vnic_selection

    @vnic_selection.setter
    def vnic_selection(self, vnic_selection):
        """
        Sets the vnic_selection of this AttachLoadBalancerDetails.
        Indicates which VNIC on each instance in the pool should be used to associate with the load balancer. Possible values are \"PrimaryVnic\" or the displayName of one of the secondary VNICs on the instance configuration that is associated with the instance pool.


        :param vnic_selection: The vnic_selection of this AttachLoadBalancerDetails.
        :type: str
        """
        self._vnic_selection = vnic_selection

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .attach_catalog_private_endpoint_details import AttachCatalogPrivateEndpointDetails
from .attribute import Attribute
from .attribute_collection import AttributeCollection
from .attribute_summary import AttributeSummary
from .attribute_tag import AttributeTag
from .attribute_tag_collection import AttributeTagCollection
from .attribute_tag_summary import AttributeTagSummary
from .base_permissions_summary import BasePermissionsSummary
from .base_tag import BaseTag
from .base_tag_summary import BaseTagSummary
from .catalog import Catalog
from .catalog_permissions_summary import CatalogPermissionsSummary
from .catalog_private_endpoint import CatalogPrivateEndpoint
from .catalog_private_endpoint_summary import CatalogPrivateEndpointSummary
from .catalog_summary import CatalogSummary
from .change_catalog_compartment_details import ChangeCatalogCompartmentDetails
from .change_catalog_private_endpoint_compartment_details import ChangeCatalogPrivateEndpointCompartmentDetails
from .connection import Connection
from .connection_alias_summary import ConnectionAliasSummary
from .connection_collection import ConnectionCollection
from .connection_summary import ConnectionSummary
from .create_attribute_details import CreateAttributeDetails
from .create_catalog_details import CreateCatalogDetails
from .create_catalog_private_endpoint_details import CreateCatalogPrivateEndpointDetails
from .create_connection_details import CreateConnectionDetails
from .create_data_asset_details import CreateDataAssetDetails
from .create_entity_details import CreateEntityDetails
from .create_folder_details import CreateFolderDetails
from .create_glossary_details import CreateGlossaryDetails
from .create_job_definition_details import CreateJobDefinitionDetails
from .create_job_details import CreateJobDetails
from .create_job_execution_details import CreateJobExecutionDetails
from .create_tag_details import CreateTagDetails
from .create_term_details import CreateTermDetails
from .create_term_relationship_details import CreateTermRelationshipDetails
from .data_asset import DataAsset
from .data_asset_collection import DataAssetCollection
from .data_asset_permissions_summary import DataAssetPermissionsSummary
from .data_asset_summary import DataAssetSummary
from .data_asset_tag import DataAssetTag
from .data_asset_tag_collection import DataAssetTagCollection
from .data_asset_tag_summary import DataAssetTagSummary
from .detach_catalog_private_endpoint_details import DetachCatalogPrivateEndpointDetails
from .entity import Entity
from .entity_collection import EntityCollection
from .entity_summary import EntitySummary
from .entity_tag import EntityTag
from .entity_tag_collection import EntityTagCollection
from .entity_tag_summary import EntityTagSummary
from .folder import Folder
from .folder_collection import FolderCollection
from .folder_summary import FolderSummary
from .folder_tag import FolderTag
from .folder_tag_collection import FolderTagCollection
from .folder_tag_summary import FolderTagSummary
from .glossary import Glossary
from .glossary_collection import GlossaryCollection
from .glossary_permissions_summary import GlossaryPermissionsSummary
from .glossary_summary import GlossarySummary
from .glossary_tree_element import GlossaryTreeElement
from .import_connection_details import ImportConnectionDetails
from .import_glossary_details import ImportGlossaryDetails
from .job import Job
from .job_collection import JobCollection
from .job_definition import JobDefinition
from .job_definition_collection import JobDefinitionCollection
from .job_definition_permissions_summary import JobDefinitionPermissionsSummary
from .job_definition_scope import JobDefinitionScope
from .job_definition_summary import JobDefinitionSummary
from .job_execution import JobExecution
from .job_execution_collection import JobExecutionCollection
from .job_execution_summary import JobExecutionSummary
from .job_log import JobLog
from .job_log_collection import JobLogCollection
from .job_log_summary import JobLogSummary
from .job_metric import JobMetric
from .job_metric_collection import JobMetricCollection
from .job_metric_summary import JobMetricSummary
from .job_summary import JobSummary
from .parse_connection_details import ParseConnectionDetails
from .property_definition import PropertyDefinition
from .search_criteria import SearchCriteria
from .search_result import SearchResult
from .search_result_collection import SearchResultCollection
from .search_tag_summary import SearchTagSummary
from .search_term_summary import SearchTermSummary
from .term import Term
from .term_associated_object import TermAssociatedObject
from .term_collection import TermCollection
from .term_relationship import TermRelationship
from .term_relationship_collection import TermRelationshipCollection
from .term_relationship_summary import TermRelationshipSummary
from .term_summary import TermSummary
from .type import Type
from .type_collection import TypeCollection
from .type_summary import TypeSummary
from .update_attribute_details import UpdateAttributeDetails
from .update_catalog_details import UpdateCatalogDetails
from .update_catalog_private_endpoint_details import UpdateCatalogPrivateEndpointDetails
from .update_connection_details import UpdateConnectionDetails
from .update_data_asset_details import UpdateDataAssetDetails
from .update_entity_details import UpdateEntityDetails
from .update_folder_details import UpdateFolderDetails
from .update_glossary_details import UpdateGlossaryDetails
from .update_job_definition_details import UpdateJobDefinitionDetails
from .update_job_details import UpdateJobDetails
from .update_term_details import UpdateTermDetails
from .update_term_relationship_details import UpdateTermRelationshipDetails
from .upload_credentials_details import UploadCredentialsDetails
from .validate_connection_details import ValidateConnectionDetails
from .validate_connection_result import ValidateConnectionResult
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log import WorkRequestLog
from .work_request_resource import WorkRequestResource

# Maps type names to classes for data_catalog services.
data_catalog_type_mapping = {
    "AttachCatalogPrivateEndpointDetails": AttachCatalogPrivateEndpointDetails,
    "Attribute": Attribute,
    "AttributeCollection": AttributeCollection,
    "AttributeSummary": AttributeSummary,
    "AttributeTag": AttributeTag,
    "AttributeTagCollection": AttributeTagCollection,
    "AttributeTagSummary": AttributeTagSummary,
    "BasePermissionsSummary": BasePermissionsSummary,
    "BaseTag": BaseTag,
    "BaseTagSummary": BaseTagSummary,
    "Catalog": Catalog,
    "CatalogPermissionsSummary": CatalogPermissionsSummary,
    "CatalogPrivateEndpoint": CatalogPrivateEndpoint,
    "CatalogPrivateEndpointSummary": CatalogPrivateEndpointSummary,
    "CatalogSummary": CatalogSummary,
    "ChangeCatalogCompartmentDetails": ChangeCatalogCompartmentDetails,
    "ChangeCatalogPrivateEndpointCompartmentDetails": ChangeCatalogPrivateEndpointCompartmentDetails,
    "Connection": Connection,
    "ConnectionAliasSummary": ConnectionAliasSummary,
    "ConnectionCollection": ConnectionCollection,
    "ConnectionSummary": ConnectionSummary,
    "CreateAttributeDetails": CreateAttributeDetails,
    "CreateCatalogDetails": CreateCatalogDetails,
    "CreateCatalogPrivateEndpointDetails": CreateCatalogPrivateEndpointDetails,
    "CreateConnectionDetails": CreateConnectionDetails,
    "CreateDataAssetDetails": CreateDataAssetDetails,
    "CreateEntityDetails": CreateEntityDetails,
    "CreateFolderDetails": CreateFolderDetails,
    "CreateGlossaryDetails": CreateGlossaryDetails,
    "CreateJobDefinitionDetails": CreateJobDefinitionDetails,
    "CreateJobDetails": CreateJobDetails,
    "CreateJobExecutionDetails": CreateJobExecutionDetails,
    "CreateTagDetails": CreateTagDetails,
    "CreateTermDetails": CreateTermDetails,
    "CreateTermRelationshipDetails": CreateTermRelationshipDetails,
    "DataAsset": DataAsset,
    "DataAssetCollection": DataAssetCollection,
    "DataAssetPermissionsSummary": DataAssetPermissionsSummary,
    "DataAssetSummary": DataAssetSummary,
    "DataAssetTag": DataAssetTag,
    "DataAssetTagCollection": DataAssetTagCollection,
    "DataAssetTagSummary": DataAssetTagSummary,
    "DetachCatalogPrivateEndpointDetails": DetachCatalogPrivateEndpointDetails,
    "Entity": Entity,
    "EntityCollection": EntityCollection,
    "EntitySummary": EntitySummary,
    "EntityTag": EntityTag,
    "EntityTagCollection": EntityTagCollection,
    "EntityTagSummary": EntityTagSummary,
    "Folder": Folder,
    "FolderCollection": FolderCollection,
    "FolderSummary": FolderSummary,
    "FolderTag": FolderTag,
    "FolderTagCollection": FolderTagCollection,
    "FolderTagSummary": FolderTagSummary,
    "Glossary": Glossary,
    "GlossaryCollection": GlossaryCollection,
    "GlossaryPermissionsSummary": GlossaryPermissionsSummary,
    "GlossarySummary": GlossarySummary,
    "GlossaryTreeElement": GlossaryTreeElement,
    "ImportConnectionDetails": ImportConnectionDetails,
    "ImportGlossaryDetails": ImportGlossaryDetails,
    "Job": Job,
    "JobCollection": JobCollection,
    "JobDefinition": JobDefinition,
    "JobDefinitionCollection": JobDefinitionCollection,
    "JobDefinitionPermissionsSummary": JobDefinitionPermissionsSummary,
    "JobDefinitionScope": JobDefinitionScope,
    "JobDefinitionSummary": JobDefinitionSummary,
    "JobExecution": JobExecution,
    "JobExecutionCollection": JobExecutionCollection,
    "JobExecutionSummary": JobExecutionSummary,
    "JobLog": JobLog,
    "JobLogCollection": JobLogCollection,
    "JobLogSummary": JobLogSummary,
    "JobMetric": JobMetric,
    "JobMetricCollection": JobMetricCollection,
    "JobMetricSummary": JobMetricSummary,
    "JobSummary": JobSummary,
    "ParseConnectionDetails": ParseConnectionDetails,
    "PropertyDefinition": PropertyDefinition,
    "SearchCriteria": SearchCriteria,
    "SearchResult": SearchResult,
    "SearchResultCollection": SearchResultCollection,
    "SearchTagSummary": SearchTagSummary,
    "SearchTermSummary": SearchTermSummary,
    "Term": Term,
    "TermAssociatedObject": TermAssociatedObject,
    "TermCollection": TermCollection,
    "TermRelationship": TermRelationship,
    "TermRelationshipCollection": TermRelationshipCollection,
    "TermRelationshipSummary": TermRelationshipSummary,
    "TermSummary": TermSummary,
    "Type": Type,
    "TypeCollection": TypeCollection,
    "TypeSummary": TypeSummary,
    "UpdateAttributeDetails": UpdateAttributeDetails,
    "UpdateCatalogDetails": UpdateCatalogDetails,
    "UpdateCatalogPrivateEndpointDetails": UpdateCatalogPrivateEndpointDetails,
    "UpdateConnectionDetails": UpdateConnectionDetails,
    "UpdateDataAssetDetails": UpdateDataAssetDetails,
    "UpdateEntityDetails": UpdateEntityDetails,
    "UpdateFolderDetails": UpdateFolderDetails,
    "UpdateGlossaryDetails": UpdateGlossaryDetails,
    "UpdateJobDefinitionDetails": UpdateJobDefinitionDetails,
    "UpdateJobDetails": UpdateJobDetails,
    "UpdateTermDetails": UpdateTermDetails,
    "UpdateTermRelationshipDetails": UpdateTermRelationshipDetails,
    "UploadCredentialsDetails": UploadCredentialsDetails,
    "ValidateConnectionDetails": ValidateConnectionDetails,
    "ValidateConnectionResult": ValidateConnectionResult,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLog": WorkRequestLog,
    "WorkRequestResource": WorkRequestResource
}



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class WafMeterDatum(object):
    """
    WafMeterDatum model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new WafMeterDatum object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param time_observed:
            The value to assign to the time_observed property of this WafMeterDatum.
        :type time_observed: datetime

        :param time_range_in_seconds:
            The value to assign to the time_range_in_seconds property of this WafMeterDatum.
        :type time_range_in_seconds: int

        :param tenancy_id:
            The value to assign to the tenancy_id property of this WafMeterDatum.
        :type tenancy_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this WafMeterDatum.
        :type compartment_id: str

        :param waas_policy_id:
            The value to assign to the waas_policy_id property of this WafMeterDatum.
        :type waas_policy_id: str

        :param is_oci_origin:
            The value to assign to the is_oci_origin property of this WafMeterDatum.
        :type is_oci_origin: bool

        :param is_bot_enabled:
            The value to assign to the is_bot_enabled property of this WafMeterDatum.
        :type is_bot_enabled: bool

        :param request_count:
            The value to assign to the request_count property of this WafMeterDatum.
        :type request_count: int

        :param traffic_in_bytes:
            The value to assign to the traffic_in_bytes property of this WafMeterDatum.
        :type traffic_in_bytes: int

        :param tag_slug:
            The value to assign to the tag_slug property of this WafMeterDatum.
        :type tag_slug: str

        """
        self.swagger_types = {
            'time_observed': 'datetime',
            'time_range_in_seconds': 'int',
            'tenancy_id': 'str',
            'compartment_id': 'str',
            'waas_policy_id': 'str',
            'is_oci_origin': 'bool',
            'is_bot_enabled': 'bool',
            'request_count': 'int',
            'traffic_in_bytes': 'int',
            'tag_slug': 'str'
        }

        self.attribute_map = {
            'time_observed': 'timeObserved',
            'time_range_in_seconds': 'timeRangeInSeconds',
            'tenancy_id': 'tenancyId',
            'compartment_id': 'compartmentId',
            'waas_policy_id': 'waasPolicyId',
            'is_oci_origin': 'isOciOrigin',
            'is_bot_enabled': 'isBotEnabled',
            'request_count': 'requestCount',
            'traffic_in_bytes': 'trafficInBytes',
            'tag_slug': 'tagSlug'
        }

        self._time_observed = None
        self._time_range_in_seconds = None
        self._tenancy_id = None
        self._compartment_id = None
        self._waas_policy_id = None
        self._is_oci_origin = None
        self._is_bot_enabled = None
        self._request_count = None
        self._traffic_in_bytes = None
        self._tag_slug = None

    @property
    def time_observed(self):
        """
        Gets the time_observed of this WafMeterDatum.
        The date and time the traffic was observed, rounded down to the start of a range, and expressed in RFC 3339 timestamp format.


        :return: The time_observed of this WafMeterDatum.
        :rtype: datetime
        """
        return self._time_observed

    @time_observed.setter
    def time_observed(self, time_observed):
        """
        Sets the time_observed of this WafMeterDatum.
        The date and time the traffic was observed, rounded down to the start of a range, and expressed in RFC 3339 timestamp format.


        :param time_observed: The time_observed of this WafMeterDatum.
        :type: datetime
        """
        self._time_observed = time_observed

    @property
    def time_range_in_seconds(self):
        """
        Gets the time_range_in_seconds of this WafMeterDatum.
        The number of seconds this data covers.


        :return: The time_range_in_seconds of this WafMeterDatum.
        :rtype: int
        """
        return self._time_range_in_seconds

    @time_range_in_seconds.setter
    def time_range_in_seconds(self, time_range_in_seconds):
        """
        Sets the time_range_in_seconds of this WafMeterDatum.
        The number of seconds this data covers.


        :param time_range_in_seconds: The time_range_in_seconds of this WafMeterDatum.
        :type: int
        """
        self._time_range_in_seconds = time_range_in_seconds

    @property
    def tenancy_id(self):
        """
        Gets the tenancy_id of this WafMeterDatum.
        The tenancy OCID of the data.


        :return: The tenancy_id of this WafMeterDatum.
        :rtype: str
        """
        return self._tenancy_id

    @tenancy_id.setter
    def tenancy_id(self, tenancy_id):
        """
        Sets the tenancy_id of this WafMeterDatum.
        The tenancy OCID of the data.


        :param tenancy_id: The tenancy_id of this WafMeterDatum.
        :type: str
        """
        self._tenancy_id = tenancy_id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this WafMeterDatum.
        The compartment OCID of the data.


        :return: The compartment_id of this WafMeterDatum.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this WafMeterDatum.
        The compartment OCID of the data.


        :param compartment_id: The compartment_id of this WafMeterDatum.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def waas_policy_id(self):
        """
        Gets the waas_policy_id of this WafMeterDatum.
        The policy OCID of the data.


        :return: The waas_policy_id of this WafMeterDatum.
        :rtype: str
        """
        return self._waas_policy_id

    @waas_policy_id.setter
    def waas_policy_id(self, waas_policy_id):
        """
        Sets the waas_policy_id of this WafMeterDatum.
        The policy OCID of the data.


        :param waas_policy_id: The waas_policy_id of this WafMeterDatum.
        :type: str
        """
        self._waas_policy_id = waas_policy_id

    @property
    def is_oci_origin(self):
        """
        Gets the is_oci_origin of this WafMeterDatum.
        True if origin (endpoint) is an OCI resource. False if external.


        :return: The is_oci_origin of this WafMeterDatum.
        :rtype: bool
        """
        return self._is_oci_origin

    @is_oci_origin.setter
    def is_oci_origin(self, is_oci_origin):
        """
        Sets the is_oci_origin of this WafMeterDatum.
        True if origin (endpoint) is an OCI resource. False if external.


        :param is_oci_origin: The is_oci_origin of this WafMeterDatum.
        :type: bool
        """
        self._is_oci_origin = is_oci_origin

    @property
    def is_bot_enabled(self):
        """
        Gets the is_bot_enabled of this WafMeterDatum.
        True if bot manager is enabled.


        :return: The is_bot_enabled of this WafMeterDatum.
        :rtype: bool
        """
        return self._is_bot_enabled

    @is_bot_enabled.setter
    def is_bot_enabled(self, is_bot_enabled):
        """
        Sets the is_bot_enabled of this WafMeterDatum.
        True if bot manager is enabled.


        :param is_bot_enabled: The is_bot_enabled of this WafMeterDatum.
        :type: bool
        """
        self._is_bot_enabled = is_bot_enabled

    @property
    def request_count(self):
        """
        Gets the request_count of this WafMeterDatum.
        The number of incoming requests.


        :return: The request_count of this WafMeterDatum.
        :rtype: int
        """
        return self._request_count

    @request_count.setter
    def request_count(self, request_count):
        """
        Sets the request_count of this WafMeterDatum.
        The number of incoming requests.


        :param request_count: The request_count of this WafMeterDatum.
        :type: int
        """
        self._request_count = request_count

    @property
    def traffic_in_bytes(self):
        """
        Gets the traffic_in_bytes of this WafMeterDatum.
        Traffic in bytes.


        :return: The traffic_in_bytes of this WafMeterDatum.
        :rtype: int
        """
        return self._traffic_in_bytes

    @traffic_in_bytes.setter
    def traffic_in_bytes(self, traffic_in_bytes):
        """
        Sets the traffic_in_bytes of this WafMeterDatum.
        Traffic in bytes.


        :param traffic_in_bytes: The traffic_in_bytes of this WafMeterDatum.
        :type: int
        """
        self._traffic_in_bytes = traffic_in_bytes

    @property
    def tag_slug(self):
        """
        Gets the tag_slug of this WafMeterDatum.
        The tag slug for the specified `waasPolicyId`.


        :return: The tag_slug of this WafMeterDatum.
        :rtype: str
        """
        return self._tag_slug

    @tag_slug.setter
    def tag_slug(self, tag_slug):
        """
        Sets the tag_slug of this WafMeterDatum.
        The tag slug for the specified `waasPolicyId`.


        :param tag_slug: The tag_slug of this WafMeterDatum.
        :type: str
        """
        self._tag_slug = tag_slug

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateOAuth2ClientCredentialDetails(object):
    """
    UpdateOAuth2ClientCredentialDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateOAuth2ClientCredentialDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this UpdateOAuth2ClientCredentialDetails.
        :type description: str

        :param scopes:
            The value to assign to the scopes property of this UpdateOAuth2ClientCredentialDetails.
        :type scopes: list[FullyQualifiedScope]

        :param is_reset_password:
            The value to assign to the is_reset_password property of this UpdateOAuth2ClientCredentialDetails.
        :type is_reset_password: bool

        """
        self.swagger_types = {
            'description': 'str',
            'scopes': 'list[FullyQualifiedScope]',
            'is_reset_password': 'bool'
        }

        self.attribute_map = {
            'description': 'description',
            'scopes': 'scopes',
            'is_reset_password': 'isResetPassword'
        }

        self._description = None
        self._scopes = None
        self._is_reset_password = None

    @property
    def description(self):
        """
        **[Required]** Gets the description of this UpdateOAuth2ClientCredentialDetails.
        Description of the oauth credential to help user differentiate them.


        :return: The description of this UpdateOAuth2ClientCredentialDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateOAuth2ClientCredentialDetails.
        Description of the oauth credential to help user differentiate them.


        :param description: The description of this UpdateOAuth2ClientCredentialDetails.
        :type: str
        """
        self._description = description

    @property
    def scopes(self):
        """
        **[Required]** Gets the scopes of this UpdateOAuth2ClientCredentialDetails.
        Allowed scopes for the given oauth credential.


        :return: The scopes of this UpdateOAuth2ClientCredentialDetails.
        :rtype: list[FullyQualifiedScope]
        """
        return self._scopes

    @scopes.setter
    def scopes(self, scopes):
        """
        Sets the scopes of this UpdateOAuth2ClientCredentialDetails.
        Allowed scopes for the given oauth credential.


        :param scopes: The scopes of this UpdateOAuth2ClientCredentialDetails.
        :type: list[FullyQualifiedScope]
        """
        self._scopes = scopes

    @property
    def is_reset_password(self):
        """
        Gets the is_reset_password of this UpdateOAuth2ClientCredentialDetails.
        Indicate if the password to be reset or not in the update.


        :return: The is_reset_password of this UpdateOAuth2ClientCredentialDetails.
        :rtype: bool
        """
        return self._is_reset_password

    @is_reset_password.setter
    def is_reset_password(self, is_reset_password):
        """
        Sets the is_reset_password of this UpdateOAuth2ClientCredentialDetails.
        Indicate if the password to be reset or not in the update.


        :param is_reset_password: The is_reset_password of this UpdateOAuth2ClientCredentialDetails.
        :type: bool
        """
        self._is_reset_password = is_reset_password

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UnifiedAgentParser(object):
    """
    source parser object.
    """

    #: A constant which can be used with the parser_type property of a UnifiedAgentParser.
    #: This constant has a value of "AUDITD"
    PARSER_TYPE_AUDITD = "AUDITD"

    #: A constant which can be used with the parser_type property of a UnifiedAgentParser.
    #: This constant has a value of "JSON"
    PARSER_TYPE_JSON = "JSON"

    #: A constant which can be used with the parser_type property of a UnifiedAgentParser.
    #: This constant has a value of "TSV"
    PARSER_TYPE_TSV = "TSV"

    #: A constant which can be used with the parser_type property of a UnifiedAgentParser.
    #: This constant has a value of "CSV"
    PARSER_TYPE_CSV = "CSV"

    #: A constant which can be used with the parser_type property of a UnifiedAgentParser.
    #: This constant has a value of "NONE"
    PARSER_TYPE_NONE = "NONE"

    #: A constant which can be used with the parser_type property of a UnifiedAgentParser.
    #: This constant has a value of "SYSLOG"
    PARSER_TYPE_SYSLOG = "SYSLOG"

    #: A constant which can be used with the parser_type property of a UnifiedAgentParser.
    #: This constant has a value of "APACHE2"
    PARSER_TYPE_APACHE2 = "APACHE2"

    #: A constant which can be used with the parser_type property of a UnifiedAgentParser.
    #: This constant has a value of "APACHE_ERROR"
    PARSER_TYPE_APACHE_ERROR = "APACHE_ERROR"

    #: A constant which can be used with the parser_type property of a UnifiedAgentParser.
    #: This constant has a value of "MSGPACK"
    PARSER_TYPE_MSGPACK = "MSGPACK"

    #: A constant which can be used with the parser_type property of a UnifiedAgentParser.
    #: This constant has a value of "REGEXP"
    PARSER_TYPE_REGEXP = "REGEXP"

    #: A constant which can be used with the parser_type property of a UnifiedAgentParser.
    #: This constant has a value of "MULTILINE"
    PARSER_TYPE_MULTILINE = "MULTILINE"

    #: A constant which can be used with the parser_type property of a UnifiedAgentParser.
    #: This constant has a value of "GROK"
    PARSER_TYPE_GROK = "GROK"

    #: A constant which can be used with the parser_type property of a UnifiedAgentParser.
    #: This constant has a value of "MULTILINE_GROK"
    PARSER_TYPE_MULTILINE_GROK = "MULTILINE_GROK"

    def __init__(self, **kwargs):
        """
        Initializes a new UnifiedAgentParser object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.logging.models.UnifiedAgentMultilineGrokParser`
        * :class:`~oci.logging.models.UnifiedJSONParser`
        * :class:`~oci.logging.models.UnifiedAgentGrokParser`
        * :class:`~oci.logging.models.UnifiedAgentNoneParser`
        * :class:`~oci.logging.models.UnifiedAgentSyslogParser`
        * :class:`~oci.logging.models.UnifiedAgentAuditdParser`
        * :class:`~oci.logging.models.UnifiedAgentApache2Parser`
        * :class:`~oci.logging.models.UnifiedAgentRegexParser`
        * :class:`~oci.logging.models.UnifiedAgentMultilineParser`
        * :class:`~oci.logging.models.UnifiedAgentTsvParser`
        * :class:`~oci.logging.models.UnifiedAgentApacheErrorParser`
        * :class:`~oci.logging.models.UnifiedAgentMsgpackParser`
        * :class:`~oci.logging.models.UnifiedAgentCsvParser`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param parser_type:
            The value to assign to the parser_type property of this UnifiedAgentParser.
            Allowed values for this property are: "AUDITD", "JSON", "TSV", "CSV", "NONE", "SYSLOG", "APACHE2", "APACHE_ERROR", "MSGPACK", "REGEXP", "MULTILINE", "GROK", "MULTILINE_GROK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type parser_type: str

        :param field_time_key:
            The value to assign to the field_time_key property of this UnifiedAgentParser.
        :type field_time_key: str

        :param types:
            The value to assign to the types property of this UnifiedAgentParser.
        :type types: dict(str, str)

        :param null_value_pattern:
            The value to assign to the null_value_pattern property of this UnifiedAgentParser.
        :type null_value_pattern: str

        :param is_null_empty_string:
            The value to assign to the is_null_empty_string property of this UnifiedAgentParser.
        :type is_null_empty_string: bool

        :param is_estimate_current_event:
            The value to assign to the is_estimate_current_event property of this UnifiedAgentParser.
        :type is_estimate_current_event: bool

        :param is_keep_time_key:
            The value to assign to the is_keep_time_key property of this UnifiedAgentParser.
        :type is_keep_time_key: bool

        :param timeout_in_milliseconds:
            The value to assign to the timeout_in_milliseconds property of this UnifiedAgentParser.
        :type timeout_in_milliseconds: int

        """
        self.swagger_types = {
            'parser_type': 'str',
            'field_time_key': 'str',
            'types': 'dict(str, str)',
            'null_value_pattern': 'str',
            'is_null_empty_string': 'bool',
            'is_estimate_current_event': 'bool',
            'is_keep_time_key': 'bool',
            'timeout_in_milliseconds': 'int'
        }

        self.attribute_map = {
            'parser_type': 'parserType',
            'field_time_key': 'fieldTimeKey',
            'types': 'types',
            'null_value_pattern': 'nullValuePattern',
            'is_null_empty_string': 'isNullEmptyString',
            'is_estimate_current_event': 'isEstimateCurrentEvent',
            'is_keep_time_key': 'isKeepTimeKey',
            'timeout_in_milliseconds': 'timeoutInMilliseconds'
        }

        self._parser_type = None
        self._field_time_key = None
        self._types = None
        self._null_value_pattern = None
        self._is_null_empty_string = None
        self._is_estimate_current_event = None
        self._is_keep_time_key = None
        self._timeout_in_milliseconds = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['parserType']

        if type == 'MULTILINE_GROK':
            return 'UnifiedAgentMultilineGrokParser'

        if type == 'JSON':
            return 'UnifiedJSONParser'

        if type == 'GROK':
            return 'UnifiedAgentGrokParser'

        if type == 'NONE':
            return 'UnifiedAgentNoneParser'

        if type == 'SYSLOG':
            return 'UnifiedAgentSyslogParser'

        if type == 'AUDITD':
            return 'UnifiedAgentAuditdParser'

        if type == 'APACHE2':
            return 'UnifiedAgentApache2Parser'

        if type == 'REGEXP':
            return 'UnifiedAgentRegexParser'

        if type == 'MULTILINE':
            return 'UnifiedAgentMultilineParser'

        if type == 'TSV':
            return 'UnifiedAgentTsvParser'

        if type == 'APACHE_ERROR':
            return 'UnifiedAgentApacheErrorParser'

        if type == 'MSGPACK':
            return 'UnifiedAgentMsgpackParser'

        if type == 'CSV':
            return 'UnifiedAgentCsvParser'
        else:
            return 'UnifiedAgentParser'

    @property
    def parser_type(self):
        """
        **[Required]** Gets the parser_type of this UnifiedAgentParser.
        type of fluent parser.

        Allowed values for this property are: "AUDITD", "JSON", "TSV", "CSV", "NONE", "SYSLOG", "APACHE2", "APACHE_ERROR", "MSGPACK", "REGEXP", "MULTILINE", "GROK", "MULTILINE_GROK", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The parser_type of this UnifiedAgentParser.
        :rtype: str
        """
        return self._parser_type

    @parser_type.setter
    def parser_type(self, parser_type):
        """
        Sets the parser_type of this UnifiedAgentParser.
        type of fluent parser.


        :param parser_type: The parser_type of this UnifiedAgentParser.
        :type: str
        """
        allowed_values = ["AUDITD", "JSON", "TSV", "CSV", "NONE", "SYSLOG", "APACHE2", "APACHE_ERROR", "MSGPACK", "REGEXP", "MULTILINE", "GROK", "MULTILINE_GROK"]
        if not value_allowed_none_or_none_sentinel(parser_type, allowed_values):
            parser_type = 'UNKNOWN_ENUM_VALUE'
        self._parser_type = parser_type

    @property
    def field_time_key(self):
        """
        Gets the field_time_key of this UnifiedAgentParser.
        Specify time field for event time. If the event doesn't have this field, current time is used.


        :return: The field_time_key of this UnifiedAgentParser.
        :rtype: str
        """
        return self._field_time_key

    @field_time_key.setter
    def field_time_key(self, field_time_key):
        """
        Sets the field_time_key of this UnifiedAgentParser.
        Specify time field for event time. If the event doesn't have this field, current time is used.


        :param field_time_key: The field_time_key of this UnifiedAgentParser.
        :type: str
        """
        self._field_time_key = field_time_key

    @property
    def types(self):
        """
        Gets the types of this UnifiedAgentParser.
        Specify types for converting field into other type.


        :return: The types of this UnifiedAgentParser.
        :rtype: dict(str, str)
        """
        return self._types

    @types.setter
    def types(self, types):
        """
        Sets the types of this UnifiedAgentParser.
        Specify types for converting field into other type.


        :param types: The types of this UnifiedAgentParser.
        :type: dict(str, str)
        """
        self._types = types

    @property
    def null_value_pattern(self):
        """
        Gets the null_value_pattern of this UnifiedAgentParser.
        Specify null value pattern


        :return: The null_value_pattern of this UnifiedAgentParser.
        :rtype: str
        """
        return self._null_value_pattern

    @null_value_pattern.setter
    def null_value_pattern(self, null_value_pattern):
        """
        Sets the null_value_pattern of this UnifiedAgentParser.
        Specify null value pattern


        :param null_value_pattern: The null_value_pattern of this UnifiedAgentParser.
        :type: str
        """
        self._null_value_pattern = null_value_pattern

    @property
    def is_null_empty_string(self):
        """
        Gets the is_null_empty_string of this UnifiedAgentParser.
        If true, empty string field is replaced with nil


        :return: The is_null_empty_string of this UnifiedAgentParser.
        :rtype: bool
        """
        return self._is_null_empty_string

    @is_null_empty_string.setter
    def is_null_empty_string(self, is_null_empty_string):
        """
        Sets the is_null_empty_string of this UnifiedAgentParser.
        If true, empty string field is replaced with nil


        :param is_null_empty_string: The is_null_empty_string of this UnifiedAgentParser.
        :type: bool
        """
        self._is_null_empty_string = is_null_empty_string

    @property
    def is_estimate_current_event(self):
        """
        Gets the is_estimate_current_event of this UnifiedAgentParser.
        If true, use Fluent::EventTime.now(current time) as a timestamp when time_key is specified


        :return: The is_estimate_current_event of this UnifiedAgentParser.
        :rtype: bool
        """
        return self._is_estimate_current_event

    @is_estimate_current_event.setter
    def is_estimate_current_event(self, is_estimate_current_event):
        """
        Sets the is_estimate_current_event of this UnifiedAgentParser.
        If true, use Fluent::EventTime.now(current time) as a timestamp when time_key is specified


        :param is_estimate_current_event: The is_estimate_current_event of this UnifiedAgentParser.
        :type: bool
        """
        self._is_estimate_current_event = is_estimate_current_event

    @property
    def is_keep_time_key(self):
        """
        Gets the is_keep_time_key of this UnifiedAgentParser.
        If true, keep time field in the record.


        :return: The is_keep_time_key of this UnifiedAgentParser.
        :rtype: bool
        """
        return self._is_keep_time_key

    @is_keep_time_key.setter
    def is_keep_time_key(self, is_keep_time_key):
        """
        Sets the is_keep_time_key of this UnifiedAgentParser.
        If true, keep time field in the record.


        :param is_keep_time_key: The is_keep_time_key of this UnifiedAgentParser.
        :type: bool
        """
        self._is_keep_time_key = is_keep_time_key

    @property
    def timeout_in_milliseconds(self):
        """
        Gets the timeout_in_milliseconds of this UnifiedAgentParser.
        Specify timeout for parse processing. This is mainly for detecting wrong regexp pattern.


        :return: The timeout_in_milliseconds of this UnifiedAgentParser.
        :rtype: int
        """
        return self._timeout_in_milliseconds

    @timeout_in_milliseconds.setter
    def timeout_in_milliseconds(self, timeout_in_milliseconds):
        """
        Sets the timeout_in_milliseconds of this UnifiedAgentParser.
        Specify timeout for parse processing. This is mainly for detecting wrong regexp pattern.


        :param timeout_in_milliseconds: The timeout_in_milliseconds of this UnifiedAgentParser.
        :type: int
        """
        self._timeout_in_milliseconds = timeout_in_milliseconds

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
